import time

import requests
from box import Box

from AndroidQQ.http import User_Agent

bot_uin = [66600000, 2854196306, 2854213893, 2854211892, 2854204259]


# 66600000 2854196306 2854213893 2854211892 2854204259

def delete_qq_friend(info, uin, fuin, bkn, cookie):
    """空间包删除好友"""

    try:
        rsp = requests.post(
            url='https://h5.qzone.qq.com/proxy/domain/w.qzone.qq.com/cgi-bin/tfriend/friend_delete_qqfriend.cgi?g_tk=' + bkn,
            data={
                'uin': uin,
                'fupdate': '1',
                'num': '1',
                'fuin': fuin,
                'format': 'json',
                'qzreferrer': f'http://user.qzone.qq.com/{uin}/myhome/friends'
            },
            headers={
                "User-Agent": User_Agent,
                "Content-Type": "application/x-www-form-urlencoded",
                "Origin": "https://h5.qzone.qq.com",
                "Referer": "https://h5.qzone.qq.com/",
                'Cookie': cookie,

            },
            proxies=info.proxy_proxies
        )
        return Box(status=True, message=f'空间请求删除好友', echo=rsp.json())
    except Exception as e:
        return Box(status=False, message=f'空间删除好友异常{e}')


class Friends:
    def __init__(self, info, bkn, uin, cookie):
        self.info = info
        self.bkn = bkn
        self.uin = uin
        self.cookie = cookie
        pass

    def add_friend(self, robot_uin):
        try:
            rsp = requests.post(url='https://qun.qq.com/cgi-bin/qunapp/robots_addfriend?bkn=' + self.bkn,
                                data={
                                    'robot_uin': robot_uin,
                                    'bkn': self.bkn
                                },
                                headers={
                                    "User-Agent": User_Agent,
                                    "Content-Type": "application/x-www-form-urlencoded",
                                    "Origin": "https://web.qun.qq.com",
                                    "X-Requested-With": "com.tencent.mobileqq",
                                    "Referer": "https://web.qun.qq.com/",
                                    "Cookie": self.cookie
                                },
                                proxies=self.info.proxy_proxies
                                )

            return Box(status=True, message=f'已请求添加好友', echo=rsp.json())

        except Exception as e:
            return Box(status=False, message=f'添加好友异常{e}')

    def del_friend(self, robot_uin):
        """删除好友"""
        try:
            rsp = requests.post(url='https://qun.qq.com/cgi-bin/qunapp/robots_removefriend?bkn=' + self.bkn,
                                data={
                                    'robot_uin': robot_uin,
                                    'bkn': self.bkn
                                },
                                headers={
                                    "User-Agent": User_Agent,
                                    "Content-Type": "application/x-www-form-urlencoded",
                                    "Origin": "https://web.qun.qq.com",
                                    "X-Requested-With": "com.tencent.mobileqq",
                                    "Referer": "https://web.qun.qq.com/",
                                    "Cookie": self.cookie
                                },
                                proxies=self.info.proxy_proxies
                                )

            return Box(status=True, message=f'已申请删除好友', echo=rsp.json())

        except Exception as e:
            return Box(status=False, message=f'删除好友异常{e}')


if __name__ == '__main__':
    print(Friends().add_friend(2854211892))
    # delete_qq_friend(2854211892, '795050525',
    #                  'uin=o1151930580; skey=MUDOsUo5A6; p_uin=o1151930580; p_skey=NL0sm39T2*NRDOc-I8J*BM6KuHKL8xSZqjYEwVVXGzM_;')

    # print(Friends().del_friend(2854211892))
    pass



User_Agent = "Mozilla/5.0 (Linux; Android 9; V1916A Build/PQ3B.190801.002; wv) AppleWebKit/537.36 (KHTML, like Gecko) Version/4.0 Chrome/91.0.4472.114 Mobile Safari/537.36 V1_AND_SQ_8.9.83_4680_YYB_D PA QQ/8.9.83.12605 NetType/WIFI WebP/0.4.1 AppId/537178647 Pixel/540 StatusBarHeight/37 SimpleUISwitch/0 QQTheme/1103 StudyMode/0 CurrentMode/0 CurrentFontScale/1.0 GlobalDensityScale/1.0 AllowLandscape/false InMagicWin/0"


from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class cmshow_active_result(IJceStruct):
    cm_cardli_count: int = 0
    cm_stone_count: int = 0
    fire_score: int = 0
    is_reach_friend_limit: int = 0
    is_reach_limit: int = 0

    def read_from(self, reader: JceReader) -> None:
        self.fire_score = reader.read_any(1)
        self.cm_stone_count = reader.read_any(2)
        self.is_reach_limit = reader.read_any(3)
        self.cm_cardli_count = reader.read_any(4)
        self.is_reach_friend_limit = reader.read_any(5)
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



# package friendlist;
from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class AddFriendReq(IJceStruct):
    adduin: int = 0
    adduinsetting: int = 0
    autoSend: int = 1
    bSupportAddRelief: bool = False
    bSupportSecureTips: bool = False
    contact_bothway_friend: bool = False
    ext_info: bytes = None
    friend_src_desc: bytes = None
    macqqInfo = None
    msg: str = ""
    msgLen: int = 0
    myAllowFlag: int = 0
    myfriendgroupid: int = 0
    name: bytes = None
    name1: bytes = None
    permission_info: bytes = None
    remark: bytes = None
    secSign: bytes = None
    showMyCard: int = 0
    sig: bytes = None
    sourceID: int = 3999
    sourceSubID: int = 0
    srcFlag: int = 0
    src_description: bytes = None
    token: bytes = None
    uin: int = 0
    verify: bytes = None

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_int64(self.uin, 0)
        Jce.write_int64(self.adduin, 1)
        Jce.write_int64(self.adduinsetting, 2)
        Jce.write_int64(self.myAllowFlag, 3)  # 我的允许标志
        Jce.write_int64(self.myfriendgroupid, 4)  # 我的朋友组 ID
        Jce.write_int64(self.msgLen, 5)  # 仅消息
        Jce.write_string(self.msg, 6)
        Jce.write_int64(self.srcFlag, 7)
        Jce.write_int64(self.autoSend, 8)
        if self.sig:
            Jce.write_object(self.sig, 9)
        Jce.write_int64(self.sourceID, 10)
        Jce.write_int64(self.sourceSubID, 11)
        if self.name:
            Jce.write_object(self.name, 12)
        if self.src_description:
            Jce.write_object(self.src_description, 13)

        if self.friend_src_desc:  # 朋友 src 描述
            Jce.write_object(self.friend_src_desc, 14)

        Jce.write_object(self.contact_bothway_friend, 15)  # 联系双向朋友
        if self.remark:
            Jce.write_object(self.remark, 16)  # 备注

        if self.name1:
            Jce.write_object(self.name1, 17)  # 姓名

        Jce.write_object(self.showMyCard, 18)  # 显示我的名片

        if self.token:
            Jce.write_object(self.token, 19)

        if self.verify:
            Jce.write_object(self.verify, 20)

        if self.macqqInfo:
            Jce.write_object(self.macqqInfo, 21)  # macqq

        Jce.write_object(self.bSupportSecureTips, 22)  # 是否支持安全提示
        Jce.write_object(self.bSupportAddRelief, 23)  # b 支持添加救济
        if self.ext_info:
            Jce.write_object(self.ext_info, 24)
        if self.secSign:
            Jce.write_object(self.secSign, 25)  # 签名
        if self.permission_infoL:
            Jce.write_object(self.permission_info, 26)  # 权限信息
        return Jce.bytes()



from Jce_b import JceReader

from .QQHeadUrlResp import *
from .DestQQHeadInfo import *

from .QQHeadUrlReq import *
from .. import PackHeadNoToken, Pack_, Un_jce_Head


def GetAvatarInfo(info, **kwargs):
    """获取头像信息"""
    _DestInfo = DestQQHeadInfo(**kwargs)
    Buffer = QQHeadUrlReq(destUserInfo=[_DestInfo], **kwargs).writeTo()
    Buffer = JceWriter().write_jce_struct(Buffer, 0)
    Buffer = JceWriter().write_map({'QQHeadUrlReq': Buffer}, 0)
    Buffer = PackHeadNoToken(info, Buffer, 'AvatarInfoSvr.QQHeadUrlReq',
                             'GetAvatarInfo', 'QQHeadUrlReq')
    Buffer = Pack_(info, Buffer, Types=11, encryption=1, sso_seq=info.seq)
    return Buffer


def GetAvatarInfo_res(Buffer):
    """获取头像信息"""
    Buffer = Un_jce_Head(Buffer)
    _map = JceReader(Buffer).read_map(0)
    QQHeadUrlResp_Buffer = _map.get('QQHeadUrlResp', None)
    qq_head_url_resp = QQHeadUrlResp()
    qq_head_url_resp.read_from(JceReader(QQHeadUrlResp_Buffer))
    return qq_head_url_resp.to_dict()



from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class Source(IJceStruct):
    apptype: int
    subtype: int
    termtype: int

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.subtype, 0)
        Jce.write_object(self.termtype, 1)
        Jce.write_object(self.apptype, 2)
        return Jce.bytes()



# struct QQService;
from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader

from AndroidQQ import log


class SvcReqGetDevLoginInfo(IJceStruct):
    iGetDevListType: int = 7
    iLoginType: int = 1
    iNextItemIndex: int = 0
    iRequireMax: int = 0
    iTimeStamp: int = 0
    strAppName: str = ""  # com.tencent.mobileqq
    vecGuid: bytes = b''

    def to_bytes(self) -> Union[bytes, bytearray]:
        jce = JceWriter()
        jce.write_bytes(self.vecGuid, 0)
        jce.write_string(self.strAppName, 1)
        jce.write_int64(self.iTimeStamp, 2)
        jce.write_int64(self.iTimeStamp, 3)
        jce.write_int64(self.iNextItemIndex, 4)
        jce.write_int64(self.iRequireMax, 5)
        jce.write_int64(self.iGetDevListType, 6)
        return jce.bytes()

    def read_from(self, reader: JceReader) -> None:
        pass


if __name__ == '__main__':
    buffer = SvcReqGetDevLoginInfo(
        # vecGuid=self.info.Guid,
        iTimeStam=1,
        strAppName='com.tencent.mobileqq',
        iRequireMax=20
    ).to_bytes()
    log.info(buffer.hex())



from Jce_b import JceWriter, JceReader

from AndroidQQ.struct import Pack_, Pack_Head, Un_jce_Head, Un_jce_Head_2
from AndroidQQ.struct.push.SvcRespRegister import SvcRespRegister


def StatSvc_register(info, Buffer):
    """
        :param info:
        :param Buffer:
        :return:
    """
    Buffer = JceWriter().write_jce_struct(Buffer, 0)

    Buffer = JceWriter().write_map({'SvcReqRegister': Buffer}, 0)
    jce = JceWriter()
    jce.write_int32(3, 1)
    jce.write_int32(0, 2)
    jce.write_int32(0, 3)
    jce.write_int64(0, 4)
    jce.write_string('PushService', 5)
    jce.write_string('SvcReqRegister', 6)
    jce.write_bytes(Buffer, 7)
    jce.write_int32(0, 8)
    Buffer = jce.bytes()
    Buffer = Buffer + bytes.fromhex('98 0C A8 0C')  # 后面的两个空的
    Buffer = Pack_Head(info, Buffer, 'StatSvc.register')
    Buffer = Pack_(info, Buffer, Types=10, encryption=1, token=True)
    return Buffer


def StatSvc_register_rsp(Buffer):
    Buffer = Un_jce_Head(Buffer)
    Buffer = Un_jce_Head_2(Buffer)
    result = JceReader(Buffer).read_object(SvcRespRegister).to_dict()
    return result



"""加密工具。

该模块用于使用 ECDH 或会话票证加密来加密数据。

：版权所有：版权所有(C)2021-2021 cscs181
：许可证：AGPL-3.0 或更高版本。有关详细信息，请参阅“许可证”。

.. _LICENSE:
    https://github.com/cscs181/CAI/blob/master/LICENSE
"""
from hashlib import md5

from cryptography.hazmat.primitives.asymmetric import ec
from cryptography.hazmat.primitives.serialization import Encoding, PublicFormat


def get_ecdh():
    _p256 = ec.SECP256R1()
    svr_public_key = ec.EllipticCurvePublicKey.from_encoded_point(
        _p256,
        bytes.fromhex(
            "04"
            "EBCA94D733E399B2DB96EACDD3F69A8BB0F74224E2B44E3357812211D2E62EFB"
            "C91BB553098E25E33A799ADC7F76FEB208DA7C6522CDB0719A305180CC54A82E"
        ),
    )

    client_private_key = ec.generate_private_key(_p256)
    client_public_key = client_private_key.public_key().public_bytes(
        Encoding.X962, PublicFormat.UncompressedPoint
    )

    share_key = md5(
        client_private_key.exchange(ec.ECDH(), svr_public_key)[:16]
    ).digest()

    return client_public_key, share_key



import json

import requests
from AndTools import TEA
from Jce import jce_to_json

from AndroidQQ.struct import Un_jce_Head


def get_sso_list():
    """获取服务器列表
    1 = host
    2 = port
    5 =protocol
    8 =city
    9 =country
    """

    response = requests.request(
        "POST",
        "https://configsvr.msf.3g.qq.com/configsvr/serverlist.jsp",
        data=bytes.fromhex(
            '97 DC AD 09 6E FC 50 91 C7 7D 0A D2 8F D9 45 A6 93 8E F3 C5 7A 44 CD BC 39 36 4D EA B1 C8 C5 50 40 88 0C 75 DA 15 37 56 A1 CA 14 1E 9B EE 2E CC 34 BF 63 13 68 13 F4 01 7B 0A 76 29 C5 40 D6 04 BB 0C 73 46 15 FA C3 F9 96 B0 AA F4 83 25 7E E7 8D 71 E1 4D 94 1E 9E 7A D8 93 EE 98 FF A8 61 0C 71 57 B7 2F 28 3A 15 63 9A CE 0F B4 BA 2E 8B 15 25 5C 7C BA 73 CC 1E 82')
    )
    if response.content:
        _data = TEA.decrypt(response.content, 'F0 44 1F 5F F4 2D A5 8F DC F7 94 9A BA 62 D4 11')
        _data = Un_jce_Head(_data[4:])
        _data = _data[27:]
        json_data = json.loads(jce_to_json(_data))
        ip_list = json_data['2']
        # print(ip_list)
        filtered_list = [x for x in ip_list if x['1'] != 'msfwifi.3g.qq.com' and x['8'] != 'sh']

        # msfwifi.3g.qq.com 同一个ip连接多了会被拒绝连接,因此删掉
        # 过滤掉上海
        return filtered_list  # 移动ip


if __name__ == '__main__':
    print(get_sso_list())



from google.protobuf.json_format import MessageToDict

from AndroidQQ.im.oidb.cmd0xeb8 import ReqBody, RspBody
from AndroidQQ.im.oidb.oidb_sso import OIDBSSOPkg
from AndroidQQ.struct import PackHeadNoToken, Pack_


def OidbSvc_0xeb8(info):
    req_body = ReqBody(
        src=1,
        proto_ver=2
    )
    oIDBSSOPkg = OIDBSSOPkg(
        command=3768,
        service_type=1,
        bodybuffer=req_body.SerializeToString(),
    )
    buffer = oIDBSSOPkg.SerializeToString()
    # print(buffer.hex())
    buffer = PackHeadNoToken(info, buffer, 'OidbSvc.0xeb8')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer


def OidbSvc_0xeb8_rep(buffer):
    oIDBSSOPkg = OIDBSSOPkg()
    oIDBSSOPkg.ParseFromString(buffer)
    rep_body = RspBody()
    rep_body.ParseFromString(oIDBSSOPkg.bodybuffer)
    return MessageToDict(rep_body)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/OidbSvc_0xc96/OidbSvc_0xc96.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3AndroidQQ/im/oidb/OidbSvc_0xc96/OidbSvc_0xc96.proto\x12\x18tencent.im.oidb.cmd0xc96\" \n\tFollowExt\x12\x13\n\x0bsource_from\x18\x01 \x01(\r\"=\n\tFollowReq\x12\x30\n\x03\x65xt\x18\x01 \x01(\x0b\x32#.tencent.im.oidb.cmd0xc96.FollowExt\"\"\n\x0bUnFollowExt\x12\x13\n\x0bsource_from\x18\x01 \x01(\r\"A\n\x0bUnfollowReq\x12\x32\n\x03\x65xt\x18\x01 \x01(\x0b\x32%.tencent.im.oidb.cmd0xc96.UnFollowExt\"\x12\n\x10GetFollowInfoReq\"$\n\x11MGetFollowInfoReq\x12\x0f\n\x07openids\x18\x01 \x03(\t\"\xd4\x02\n\x07ReqBody\x12\r\n\x05\x61ppid\x18\x01 \x01(\x04\x12\x10\n\x08\x61pp_type\x18\x02 \x01(\r\x12\x0c\n\x04puin\x18\x03 \x01(\x04\x12\x10\n\x08\x63md_type\x18\x04 \x01(\r\x12\x37\n\nfollow_req\x18\x0b \x01(\x0b\x32#.tencent.im.oidb.cmd0xc96.FollowReq\x12;\n\x0cunfollow_req\x18\x0c \x01(\x0b\x32%.tencent.im.oidb.cmd0xc96.UnfollowReq\x12G\n\x13get_follow_info_req\x18\r \x01(\x0b\x32*.tencent.im.oidb.cmd0xc96.GetFollowInfoReq\x12I\n\x14mget_follow_info_req\x18\x0e \x01(\x0b\x32+.tencent.im.oidb.cmd0xc96.MGetFollowInfoReq\";\n\x07RspBody\x12\x0f\n\x07wording\x18\x01 \x01(\t\x12\r\n\x05\x61ppid\x18\x03 \x01(\x04\x12\x10\n\x08\x61pp_type\x18\x04 \x01(\x04')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.OidbSvc_0xc96.OidbSvc_0xc96_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_FOLLOWEXT']._serialized_start=81
  _globals['_FOLLOWEXT']._serialized_end=113
  _globals['_FOLLOWREQ']._serialized_start=115
  _globals['_FOLLOWREQ']._serialized_end=176
  _globals['_UNFOLLOWEXT']._serialized_start=178
  _globals['_UNFOLLOWEXT']._serialized_end=212
  _globals['_UNFOLLOWREQ']._serialized_start=214
  _globals['_UNFOLLOWREQ']._serialized_end=279
  _globals['_GETFOLLOWINFOREQ']._serialized_start=281
  _globals['_GETFOLLOWINFOREQ']._serialized_end=299
  _globals['_MGETFOLLOWINFOREQ']._serialized_start=301
  _globals['_MGETFOLLOWINFOREQ']._serialized_end=337
  _globals['_REQBODY']._serialized_start=340
  _globals['_REQBODY']._serialized_end=680
  _globals['_RSPBODY']._serialized_start=682
  _globals['_RSPBODY']._serialized_end=741
# @@protoc_insertion_point(module_scope)



import requests
import json

from AndroidQQ.http import User_Agent
from AndroidQQ.utils import qq_bkn


def WriteMindJar(info, cookie: str, skey: str):
    """心灵罐子签到"""
    try:
        response = requests.post(
            url="https://ti.qq.com/qqsignin/mindjar/trpc/WriteMindJar",
            params={
                "bkn": qq_bkn(skey),
            },
            headers={
                "Host": "ti.qq.com",
                "Connection": "keep-alive",
                "Accept": "application/json, text/plain, */*",
                "User-Agent": User_Agent,
                "Content-Type": "application/json",
                "Origin": "https://ti.qq.com",
                "X-Requested-With": "com.tencent.mobileqq",
                "Sec-Fetch-Site": "same-origin",
                "Sec-Fetch-Mode": "cors",
                "Sec-Fetch-Dest": "empty",
                "Referer": "https://ti.qq.com/signin/public/index.html?_wv=1090528161&_wwv=13",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": cookie,
            },
            data=json.dumps({}),
            proxies=info.proxy_proxies
        )
        return response.json()
    except requests.exceptions.ProxyError as e:
        return {"errcode": -2, "errmsg": f'代理异常{e}'}
    except requests.exceptions.RequestException:
        return {"errcode": -1, "errmsg": '请求异常'}

# if __name__ == '__main__':



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: oidb_0x88d.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10oidb_0x88d.proto\x12\x10im.oidb.cmd0x88d\"O\n\tGroupInfo\x12\x13\n\x0bgroup_owner\x18\x01 \x01(\x04\x12\x17\n\x0fgroup_class_ext\x18\x07 \x01(\r\x12\x14\n\x0cgroup_answer\x18\x18 \x01(\t\"v\n\x0cReqGroupInfo\x12\x12\n\ngroup_code\x18\x01 \x01(\x04\x12\x30\n\x0bstgroupinfo\x18\x02 \x01(\x0b\x32\x1b.im.oidb.cmd0x88d.GroupInfo\x12 \n\x18last_get_group_name_time\x18\x03 \x01(\r\"i\n\x07ReqBody\x12\r\n\x05\x61ppid\x18\x01 \x01(\r\x12\x34\n\x0creqgroupinfo\x18\x02 \x03(\x0b\x32\x1e.im.oidb.cmd0x88d.ReqGroupInfo\x12\x19\n\x11pc_client_version\x18\x03 \x01(\r\"d\n\x0cRspGroupInfo\x12\x12\n\ngroup_code\x18\x01 \x01(\x04\x12\x0e\n\x06result\x18\x02 \x01(\r\x12\x30\n\x0bstgroupinfo\x18\x03 \x01(\x0b\x32\x1b.im.oidb.cmd0x88d.GroupInfo\"O\n\x07RspBody\x12\x31\n\tgroupinfo\x18\x01 \x03(\x0b\x32\x1e.im.oidb.cmd0x88d.RspGroupInfo\x12\x11\n\terrorinfo\x18\x02 \x01(\x0c')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'oidb_0x88d_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GROUPINFO']._serialized_start=38
  _globals['_GROUPINFO']._serialized_end=117
  _globals['_REQGROUPINFO']._serialized_start=119
  _globals['_REQGROUPINFO']._serialized_end=237
  _globals['_REQBODY']._serialized_start=239
  _globals['_REQBODY']._serialized_end=344
  _globals['_RSPGROUPINFO']._serialized_start=346
  _globals['_RSPGROUPINFO']._serialized_end=446
  _globals['_RSPBODY']._serialized_start=448
  _globals['_RSPBODY']._serialized_end=527
# @@protoc_insertion_point(module_scope)



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader
from .s_arkshare import s_arkshare


class s_outshare(IJceStruct):
    action_url: str = ""
    ark_sharedata: IJceStruct = None
    photourl: dict = None  # 懒的折腾
    summary: str = ""
    title: str = ""

    def read_from(self, reader: JceReader) -> None:
        self.title = reader.read_any(0)
        self.summary = reader.read_any(1)
        self.photourl = reader.read_any_with_tag(2)
        self.ark_sharedata = reader.read_object(s_arkshare)
        self.action_url = reader.read_any(4)
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



from Jce_b import JceWriter, JceReader

from AndroidQQ.struct import PackHead_QMF
from AndroidQQ.struct.NS_MOBILE_COMM import UgcRightInfo
from AndroidQQ.struct.NS_MOBILE_OPERATION import OperationPublishmoodReq, Source, operation_publishmood_rsp
from AndroidQQ.struct.cooperation import createQmfUpstream, UnQmfDownstream


def SQQzoneSvc_publishmood(info, content: str):
    """"
    空间_说说
        :param info
        :param content 发送的内容

    # """
    busi_param = {
        32: '0',
        33: '0',
        25: '',  # 自身的名字
        41: 'quickpic_use=0'
    }

    source = Source(
        # 来源
        subtype=2,
        termtype=4,
        apptype=0
    )

    right_info = UgcRightInfo(
        # UGC 权利信息
        ugc_right=1
    )

    extend_info = {
        'is_feeds_long_pics_browsing_mode': '0'  # 是提供长图片浏览模式
    }
    stored_extend_info = {
        'is_feeds_long_pics_browsing_mode': '0',  # 是提供长图片浏览模式
        'fakeFeedAppIdForClient': '311'  # 客户端的虚假 Feed 应用程序 ID
    }
    proto_extend_info = {
        'TO_UGCSVR_FOR_FONT': bytes(b'\x0c\x1c'),
        '#CHARBUF#feedskin': bytes(b'\x08\x0c'),
    }

    PublishmoodReq = OperationPublishmoodReq(
        uin=int(info.uin),
        content=content,
        isverified=1,  # 已验证
        issynctoweibo=0,

        source=source,
        busi_param=busi_param,
        # clientkey='94ccc310-d2a2-4c32-bebf-f68435c30698',
        open_appid='',
        right_info=right_info,
        extend_info=extend_info,
        stored_extend_info=stored_extend_info,
        proto_extend_info=proto_extend_info
        #
    ).to_bytes()
    #

    OperationLikeReq = JceWriter().write_jce_struct(PublishmoodReq, 0)

    int64 = JceWriter().write_int64(int(info.uin), 0).bytes()

    Buffer = JceWriter().write_map({'publishmood': {
        'NS_MOBILE_OPERATION.operation_publishmood_req': OperationLikeReq
    }, 'hostuin': {'int64': int64}}, 0)

    Upstream = createQmfUpstream(info, 1, Buffer, 'QzoneNewService.publishmood')
    Buffer = PackHead_QMF(info, 'SQQzoneSvc.publishmood', Upstream)

    return Buffer


def SQQzoneSvc_publishmood_rsp(buffer: bytes) -> dict:
    rsp_Buffer, msg, ret = UnQmfDownstream(buffer, 'publishmood', 'NS_MOBILE_OPERATION.operation_publishmood_rsp')

    if rsp_Buffer == b'':
        return {'Busi': {}, 'msg': msg, 'ret': ret}
    like_rsp = JceReader(rsp_Buffer).read_object(operation_publishmood_rsp)
    return {'Busi': like_rsp.to_dict(), 'msg': msg, 'ret': ret}


if __name__ == '__main__':
    SQQzoneSvc_publishmood('测试说说')



# package QMF_PROTOCAL;
from typing import Union

from Jce_b import IJceStruct, JceReader, JceWriter


class RetryInfo(IJceStruct):
    Flag: int = 0
    PkgId: int = 0
    RetryCount: int = 0

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.Flag, 0)
        Jce.write_object(self.RetryCount, 1)
        Jce.write_object(self.PkgId, 2)

        return Jce.bytes()



from google.protobuf.json_format import MessageToDict

from AndroidQQ.im.oidb.OidbSvc_0xc96 import ReqBody, UnfollowReq, UnFollowExt, RspBody
from AndroidQQ.im.oidb.oidb_sso import OIDBSSOPkg
from AndroidQQ.struct import PackHeadNoToken, Pack_


def OidbSvc_0xc96(info, puin: int, cmd_type: int) -> bytes:
    reqBody = ReqBody(
        puin=puin,  # ,3
        cmd_type=cmd_type,  # 4
        unfollow_req=UnfollowReq(
            # 12
            ext=UnFollowExt(
                source_from=1  # 来源?
            )
        )
    )
    oIDBSSOPkg = OIDBSSOPkg(
        command=3222,
        service_type=0,
        result=0,
        bodybuffer=reqBody.SerializeToString(),
    )
    buffer = oIDBSSOPkg.SerializeToString()

    buffer = PackHeadNoToken(info, buffer, 'OidbSvc.0xc96')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer


def OidbSvc_0xc96_rsp(buffer: bytes):
    oIDBSSOPkg = OIDBSSOPkg()
    oIDBSSOPkg.ParseFromString(buffer)
    rep_body = RspBody()
    rep_body.ParseFromString(oIDBSSOPkg.bodybuffer)
    return MessageToDict(rep_body)


if __name__ == '__main__':
    pass



import time
from urllib.parse import urlparse, parse_qs

import requests
from box import Box

from AndroidQQ.http import User_Agent


class credit_score:

    def __init__(self, info, clientkey):
        # self.uin = '3484129139'
        # self.clientkey = '9f2677a5c3c9dd3571f4c14c3a796f06cd54ade8e7983f68b2e8bdb557e65eabc849b9b87cf8a6ed69f2a3e4b99d2dde'
        #
        self.gs_code = None
        self.uin = info.uin
        self.clientkey = clientkey
        self.info = info
        self.get_gs_code()

    def get_gs_code(self):
        try:
            response = requests.get(url="https://ssl.ptlogin2.qq.com/jump",
                                    params={
                                        "keyindex": "19",
                                        "clientuin": self.uin,
                                        "clientkey": self.clientkey,
                                        "u1": "https://connect.qq.com",
                                        "pt_report": "1",
                                        "pt_aid": "716027609",
                                        "daid": "383",
                                        "style": "35",
                                        "pt_ua": "B0BFB00844CA89BF32B35D60533238A2",
                                        "pt_browser": "Chrome",
                                        "pt_3rd_aid": "102053620",
                                        "pt_openlogin_data": f"appid=716027609&pt_3rd_aid=102053620&daid=383&pt_skey_valid=0&style=35&s_url=https%3A%2F%2Fconnect.qq.com&refer_cgi=authorize&which=&sdkp=pcweb&sdkv=v1.0&time={str(int(time.time()))}&loginty=3&h5sig=G_tqev5eSttaANNnVgcw5gCN25vuzK7ef9fUPcYGmUY&state=qqconnect_1&client_id=102053620&response_type=code&scope=all&redirect_uri=https%3A%2F%2Fgamecredit.qq.com%2Flogin-ui%2Findex.html%3FcPageName%3Dmiddle%26type%3DQQ%26backUrl%3Dreload%26appId%3D102053620&pt_flex=1&loginfrom=&h5sig=G_tqev5eSttaANNnVgcw5gCN25vuzK7ef9fUPcYGmUY&loginty=3&",
                                    }
                                    ,
                                    allow_redirects=False,
                                    proxies=self.info.proxy_proxies
                                    )
            Location = response.headers['Location']

            if Location is None:
                return {'status': False, 'message': '没找到Location'}
            parsed_url = urlparse(Location)
            query_params = parse_qs(parsed_url.query)
            code = query_params.get('code')[0]
            response = requests.get(url=f'https://gamecredit.qq.com/connect?code={code}&appId=102053620&atype=QQ',
                                    allow_redirects=False,
                                    proxies=self.info.proxy_proxies
                                    )
            self.gs_code = response.cookies.get('gs_code')
            if self.gs_code is None:
                return {'status': False, 'message': '没找到gs_code'}
            return {'status': True, 'cookie': self.gs_code}
        except Exception as e:
            return {'status': False, 'message': f'获取gs_code异常:{e}'}

    def query_common_credit(self):
        if not self.gs_code:
            return {'status': False, 'message': 'gs_code为空', 'score': 0}

        try:
            response = requests.get(
                url="https://gamecredit.qq.com/api/qq/proxy/query_common_credit",
                headers={
                    "Host": "gamecredit.qq.com",
                    "Connection": "keep-alive",
                    "Accept": "application/json, text/plain, */*",
                    "Content-Type": "application/x-www-form-urlencoded",
                    "sec-ch-ua-mobile": "?0",
                    "User-Agent": User_Agent,
                    "Sec-Fetch-Site": "same-origin",
                    "Sec-Fetch-Mode": "cors",
                    "Sec-Fetch-Dest": "empty",
                    "Referer": "https://gamecredit.qq.com/static/web/index.html",
                    "Accept-Encoding": "gzip, deflate, br, zstd",
                    "Accept-Language": "zh-CN,zh;q=0.9",
                    "Cookie": "gs_code=" + self.gs_code,
                },
                proxies=self.info.proxy_proxies
            )
            data = response.json().get('data', {})
            score = data.get('score', -1)
            return {'status': True, 'score': score, 'data': data}
        except requests.exceptions.RequestException:
            return {'status': False, 'score': 0, 'message': '请求失败'}


if __name__ == '__main__':
    pass
    # print(credit_score().query_common_credit())
    # query_common_credit()
#
# ptui_qlogin()

# send_request()
# connect()

# query_common_credit()



# package QMF_PROTOCAL;
from typing import Union

from Jce_b import IJceStruct, JceReader, JceWriter


class QmfTokenInfo(IJceStruct):
    Key: bytes = b''
    Type: int = 0
    ext_key: dict = {}

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.Type, 0)
        Jce.write_object(self.Key, 1)
        if self.ext_key is not None:
            Jce.write_map(self.ext_key, 2)

        return Jce.bytes()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/scanlogin/scanlogin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+AndroidQQ/im/oidb/scanlogin/scanlogin.proto\"3\n\x0cScanLoginReq\x12\x14\n\x0cservice_type\x18\x02 \x01(\x05\x12\r\n\x05token\x18\x03 \x01(\x0c\"N\n\x0cScanLoginRsp\x12\x0e\n\x06\x66ield1\x18\x01 \x01(\x05\x12\x0e\n\x06\x66ield2\x18\x02 \x01(\x05\x12\x0e\n\x06\x66ield3\x18\x03 \x01(\x05\x12\x0e\n\x06\x66ield4\x18\x04 \x01(\x0c')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.scanlogin.scanlogin_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SCANLOGINREQ']._serialized_start=47
  _globals['_SCANLOGINREQ']._serialized_end=98
  _globals['_SCANLOGINRSP']._serialized_start=100
  _globals['_SCANLOGINRSP']._serialized_end=178
# @@protoc_insertion_point(module_scope)



from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class QmfBusiControl(IJceStruct):
    compFlag: int
    lenBeforeComp: int
    rspCompFlag: int

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.compFlag, 0)
        Jce.write_object(self.lenBeforeComp, 1)
        Jce.write_object(self.compFlag, 2)
        return Jce.bytes()



import struct
import time

from AndTools import pack_b, get_random_bin, get_md5, TEA, pack_u

from AndroidQQ import log
from AndroidQQ.proto import DeviceReport


def Tlv_head(head, data):
    pack = pack_b()
    pack.add_Hex(head)
    pack.add_int(len(data), 2)
    pack.add_bin(data)
    return pack.get_bytes()


class TLV:
    def __init__(self, info):
        self.pack = pack_b()
        self.info = info

    def T018(self):
        self.pack.empty()
        self.pack.add_Hex('00 01 00 00 06 00 00 00 00 10 00 00 00 00')
        self.pack.add_int(int(self.info.uin))
        self.pack.add_Hex('00 00 00 00')
        return Tlv_head('00 18', self.pack.get_bytes())

    def T001(self):
        self.pack.empty()
        self.pack.add_Hex('00 01')  # ip_version
        self.pack.add_bin(get_random_bin(4))
        self.pack.add_int(int(self.info.uin))
        self.pack.add_int(int(time.time()))  # server_time
        self.pack.add_Hex('00 00 00 00')  # ip
        self.pack.add_Hex('00 00')
        _data = self.pack.get_bytes()

        return Tlv_head('00 01', _data)

    def T017(self, app_id: int, Uin: int, login_time: int):
        self.pack.empty()
        self.pack.add_Hex('00 16 00 01')
        self.pack.add_Hex('00 00 06 00')
        self.pack.add_int(app_id)
        self.pack.add_Hex('00 00 00 00')
        self.pack.add_int(Uin)
        self.pack.add_Hex('00 00 00 00')
        return Tlv_head('00 17', self.pack.get_bytes())

    def T142(self):
        self.pack.empty()
        self.pack.add_body(self.info.device.package_name, 4)
        return Tlv_head('01 42', self.pack.get_bytes())

    def T016(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 05')
        self.pack.add_Hex('00 00 00 10')  # len
        self.pack.add_Hex('20 04 1E EE 9B 6B E0 65 3A 35 6F 4F AC 89 92 6F 3F 1C EB 7E')
        self.pack.add_body('com.tencent.qqlite', 2)
        self.pack.add_body('2.1.7', 2)
        self.pack.add_Hex('00 10')  # len
        self.pack.add_Hex('A6 B7 45 BF 24 A2 C2 77 52 77 16 F6 F3 6E B6 8D')
        return Tlv_head('00 16', self.pack.get_bytes())

    def T01B(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 00 00 00 00 00 00 00 00 08 00 00 00 04 00 00 00 48 00 00 00 02 00 00 00 02 00 00 ')
        return Tlv_head('00 1B', self.pack.get_bytes())

    def T01D(self):
        self.pack.empty()
        self.pack.add_Hex('01 00 F7 FF 7C 00 00 00 00 00 00 00 00 00')
        return Tlv_head('00 1D', self.pack.get_bytes())

    def T01F(self):
        self.pack.empty()
        self.pack.add_Hex('01')
        self.pack.add_Hex('00 07')  # android len
        self.pack.add_Hex('61 6E 64 72 6F 69 64')  # android
        self.pack.add_Hex('00 01')
        self.pack.add_Hex('39')
        self.pack.add_Hex('00 02')
        self.pack.add_Hex('00 10')  # len
        self.pack.add_Hex('43 68 69 6E 61 20 4D 6F 62 69 6C 65 20 47 53 4D')  # China Mobile GSM
        self.pack.add_Hex('00 00 00 04')
        self.pack.add_Hex('77 69 66 69')  # wifi
        return Tlv_head('00 1F', self.pack.get_bytes())

    def T033(self):
        self.pack.empty()
        self.pack.add_bin(get_random_bin(16))
        return Tlv_head('00 33', self.pack.get_bytes())

    def T035(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 73')
        return Tlv_head('00 35', self.pack.get_bytes())

    def T106(self):
        self.pack.empty()
        if self.info.device.client_type == 'Watch':
            self.pack.add_bin(self.info.UN_Tlv_list.T018)
            _data = self.pack.get_bytes()
            # Token0106
        else:
            password_md5 = get_md5(self.info.password.encode('utf-8'))
            hex_uin = int(self.info.uin).to_bytes(4, 'big')
            self.pack.add_Hex('00 04')  # tgtgt version
            self.pack.add_bin(get_random_bin(4))
            self.pack.add_Hex('00 00 00 12 ')  # sso_version
            self.pack.add_Hex('00 00 00 10')  # app_id
            self.pack.add_Hex('00 00 00 00')  # app_client_version
            self.pack.add_Hex('00 00 00 00')
            self.pack.add_int(int(self.info.uin))
            self.pack.add_int(self.info.login_time)
            self.pack.add_Hex('00 00 00 00 01')
            self.pack.add_bin(password_md5)
            self.pack.add_bin(self.info.key_tgtgt)
            self.pack.add_Hex('00 00 00 00 01')
            self.pack.add_bin(self.info.Guid)
            self.pack.add_int(self.info.device.app_id)
            self.pack.add_Hex('00 00 00 01')  # login_type
            self.pack.add_body(self.info.uin, 2)
            self.pack.add_Hex('00 00')
            _data = self.pack.get_bytes()

            _key = get_md5(password_md5 + bytes.fromhex('00 00 00 00') + hex_uin)
            _data = TEA.encrypt(_data, _key)

        return Tlv_head('01 06', _data)

    def T116(self, image_type=10):
        self.pack.empty()
        if self.info.device.client_type == 'Watch':
            self.pack.add_Hex('00 00 F7 FF 7C 00 01 04 00 00')
        elif self.info.device.client_type == 'QQ':
            self.pack.add_int(image_type, 2)
            self.pack.add_Hex('F7 FF 7C 00 01 04 00 01 5F 5E 10 E2')
        else:
            _data = b''
        _data = self.pack.get_bytes()

        return Tlv_head('01 16', _data)

    def T100(self, sso_version, app_id, app_client_version, sigmap):

        self.pack.empty()
        self.pack.add_Hex('00 01')
        self.pack.add_int(sso_version)
        self.pack.add_int(app_id)
        self.pack.add_int(self.info.device.app_id)
        self.pack.add_int(app_client_version)
        self.pack.add_int(sigmap)
        _data = self.pack.get_bytes()

        return Tlv_head('01 00', _data)

    def T104(self):
        _data = self.info.UN_Tlv_list.T104_captcha
        log.info("104", _data.hex())

        # _data = bytes.fromhex(
        #     '41 72 73 77 7A 7A 43 6E 6D 4E 78 4A 5A 47 69 36 42 66 78 77 46 4B 4F 33 59 5A 5A 34 44 6B 6D 69 44 67 3D 3D')
        # log.info(_data)
        # _data = b'Ai2wAWtEB75HUgAq+mzGjldzYRSjS/jceQ=='
        return Tlv_head('01 04', _data)

    def T107(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 00 00 01 ')
        return Tlv_head('01 07', self.pack.get_bytes())

    def T109(self):

        self.pack.empty()
        self.pack.add_bin(get_md5(self.info.device.android_id))
        return Tlv_head('01 09', self.pack.get_bytes())

    def T124(self):
        self.pack.empty()
        temp = '39'  # todo 不确定是什么,后面和普通安卓进行对比再确认
        self.pack.add_body(self.info.device.name, 2)
        self.pack.add_body(temp, 2, True)
        self.pack.add_int(2, 2)
        self.pack.add_body(self.info.device.internet, 2)
        self.pack.add_body(self.info.device.internet_type, 4)
        print(self.pack.get_bytes().hex())
        return Tlv_head('01 24', self.pack.get_bytes())

    def T128(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 01 01 00 11 00 00 00')
        self.pack.add_body(self.info.device.model, 2)
        self.pack.add_body(self.info.Guid, 2)
        self.pack.add_body(self.info.device.brand, 2)
        return Tlv_head('01 28', self.pack.get_bytes())

    def T16E(self):
        self.pack.empty()
        self.pack.add_body(self.info.device.model, 2)
        return Tlv_head('01 6E', self.pack.get_bytes())

    def T52D(self):
        device_info = DeviceReport(
            bootloader='unknown',
            proc_version='Linux version 4.4.146 (build@ubuntu) (gcc version 4.8 (GCC) ) #1 SMP PREEMPT Thu Sep 1 '
                         '18:26:33 CST 2022',
            codename='REL',
            incremental='G9650ZHU2ARC6',
            fingerprint='samsung/star2qltezh/star2qltechn:9/PQ3B.190801.002/G9650ZHU2ARC6:user/release-keys',
            boot_id=self.info.device.boot_id,
            android_id=self.info.device.android_id.hex(),
            base_band='',
            inner_version='G9650ZHU2ARC6',
        )
        return Tlv_head('05 2D', device_info.SerializeToString())

    def T144(self):
        pack = pack_b()

        if self.info.device.client_type == 'Watch':
            methods = {
                self.T109,
                self.T124,
                self.T128,
                self.T16E,
            }
        else:
            methods = {
                self.T109,
                self.T52D,
                self.T124,
                self.T128,
                self.T16E,
            }

        pack.add_int(len(methods), 2)  # 数量
        # 循环调用每一个方法，并将结果添加到包中
        for method in methods:
            pack.add_bin(method())
        _data = pack.get_bytes()
        _data = TEA.encrypt(_data, self.info.key_tgtgt)

        return Tlv_head('01 44', _data)

    def T145(self):
        """GUid"""

        return Tlv_head('01 45', self.info.Guid)

    def T147(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 10')
        self.pack.add_body(self.info.device.version, 2, )
        self.pack.add_body(self.info.device.Sig, 2, True)
        _data = self.pack.get_bytes()
        return Tlv_head('01 47', _data)

    def T511(self):
        """
            office.qq.com
            qun.qq.comgamecenter.qq.comdocs.qq.commail.qq.com	ti.qq.com
            vip.qq.com
            tenpay.comqqweb.qq.comqzone.qq.com
            mma.qq.comgame.qq.comopenmobile.qq.comconnect.qq.com"""

        domain = [
            'office.qq.com',
            'qun.qq.com',
            'gamecenter.qq.com',
            # 'graph.qq.com',
            # 'docs.qq.com',
            'mail.qq.com',
            'ti.qq.com',
            'vip.qq.com',
            # 'tenpay.com',
            'qqweb.qq.com',
            'qzone.qq.com',
            'mma.qq.com',
            'game.qq.com',
            # 'openmobile.qq.com',
            'connect.qq.com',
            'accounts.qq.com',
            # 'weishi.qq.com',

        ]
        self.pack.empty()
        self.pack.add_int(len(domain), 2)  # 数量
        for domain_result in domain:
            self.pack.add_Hex('01')
            self.pack.add_body(domain_result, 2)

        # print(self.pack.get_bytes().hex())

        return Tlv_head('05 11', self.pack.get_bytes())

    def T16A(self):
        self.pack.empty()
        self.pack.add_bin(self.info.UN_Tlv_list.T019)
        return Tlv_head('01 6A', self.pack.get_bytes())

    def T154(self):
        self.pack.empty()
        self.pack.add_int(self.info.seq)
        return Tlv_head('01 54', self.pack.get_bytes())

    def T141(self):
        self.pack.empty()
        self.pack.add_Hex('00 01')
        self.pack.add_body(self.info.device.internet, 2)
        self.pack.add_Hex('00 02')
        self.pack.add_body(self.info.device.internet_type, 2)
        _data = self.pack.get_bytes()
        return Tlv_head('01 41', _data)

    def T008(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 00 08 04 00 00')
        return Tlv_head('00 08', self.pack.get_bytes())

    def T187(self):
        Mac = get_md5(self.info.device.Mac)
        self.pack.empty()
        self.pack.add_body(Mac, 2)
        _data = self.pack.get_bytes()
        return Tlv_head('01 87', _data)

    def T188(self):
        _app_id = get_md5(str(self.info.device.app_id))

        self.pack.empty()
        self.pack.add_body(_app_id, 2)
        _data = self.pack.get_bytes()
        return Tlv_head('01 88', _data)

    def T193(self, Ticket):
        return Tlv_head('01 93', Ticket.encode())

    def T194(self):
        _IMEI = get_md5(self.info.device.Imei)
        self.pack.empty()
        self.pack.add_body(_IMEI, 2)
        return Tlv_head('01 94', self.pack.get_bytes())

    def T191(self, can_web_verify):
        self.pack.empty()

        self.pack.add_Hex(can_web_verify)

        return Tlv_head('01 91', self.pack.get_bytes())

    def T202(self):
        Bssid = get_md5(self.info.device.Bssid)
        self.pack.empty()
        self.pack.add_body(Bssid, 2)
        self.pack.add_body('<unknown ssid>', 2)
        _data = self.pack.get_bytes()
        return Tlv_head('02 02', _data)

    def T177(self):
        self.pack.empty()
        self.pack.add_Hex('01')
        self.pack.add_int(self.info.device.build_time)
        self.pack.add_body(self.info.device.sdk_version, 2)
        _data = self.pack.get_bytes()
        return Tlv_head('01 77', _data)

    def T516(self):
        self.pack.empty()
        self.pack.add_Hex('00 00 00 00')  # source_type
        return Tlv_head('05 16', self.pack.get_bytes())

    def T521(self, product_type: int):

        _data = struct.pack(">IH", product_type, 0)
        return Tlv_head('05 21', _data)

    def T525(self, _hex):
        self.pack.empty()
        self.pack.add_Hex(_hex)
        return Tlv_head('05 25', self.pack.get_bytes())

    def T318(self):
        self.pack.empty()
        self.pack.add_bin(self.info.UN_Tlv_list.T065)
        return Tlv_head('03 18', self.pack.get_bytes())

    def T544(self):
        self.pack.empty()
        self.pack.add_Hex(
            '68656861000000010100000000000000010100050000000000F3139D7900000002000000A6000100080000018A412D97310002000A7261262364366224377100030004010000010005000401000001000400040000000000060004010000040007000401000005000800040100000600090020C55E51B0542E079D3857E4E7B349855D55668F94A819085EDF5E9C4D07FFBE0B000A0010520A4AA351000C9880A69945B72FE817000B00103BB4D57F3F48F674183F22D1B307BFC6000C000401000001000D000400000000')
        return Tlv_head('05 44', self.pack.get_bytes())

    def T545(self):
        self.pack.empty()
        self.pack.add_Hex(
            '303863376639353563653831646230636361343862636135313030303137353137343062')
        return Tlv_head('05 45', self.pack.get_bytes())

    def T547(self):
        T546 = self.info.UN_Tlv_list.T546_captcha
        part1 = T546[8:]
        _pack_u = pack_u(part1)
        _len = _pack_u.get_int(2)
        part2 = _pack_u.get_bin(_len)

        add_short = int.from_bytes(part2[-2:], 'big') + 10000
        add_bin = add_short.to_bytes(2, 'big')
        part2 = part2[:-2] + add_bin

        self.pack.empty()
        self.pack.add_Hex('01 02 01 01 01 00 00 00')
        self.pack.add_bin(part1)
        self.pack.add_body(part2, 2)
        self.pack.add_Hex('00 00 00 21')
        self.pack.add_Hex('00 00 27 10')
        _data = self.pack.get_bytes()
        return Tlv_head('05 47', _data)

    def T548(self):
        self.pack.empty()
        self.pack.add_Hex(
            '01020101000A0000008079E7CD8994B25D1E7330EDB1ED1A05A64B06135BDBE39F4B06482AB4B8D1744D972DA34482C9B2C01A3D743F8AFAC78D5A77A6AE4A9B016B9C7597795EB1754EFF259A02D5725D065D4C92F46C173669CE4C7E1E06C8F8AA996C096489ECAAE767092F78E6F9C5AA284D284D05B307E824507565224BD92D12D6DF5168DFBB4B0020B9D19B2A3E26BECD3384D94C85D78914FAC6E00C2D128F5EF674F6DEB046E91B00AC01020102000A0000008079E7CD8994B25D1E7330EDB1ED1A05A64B06135BDBE39F4B06482AB4B8D1744D972DA34482C9B2C01A3D743F8AFAC78D5A77A6AE4A9B016B9C7597795EB1754EFF259A02D5725D065D4C92F46C173669CE4C7E1E06C8F8AA996C096489ECAAE767092F78E6F9C5AA284D284D05B307E824507565224BD92D12D6DF5168DFBB4B0020B9D19B2A3E26BECD3384D94C85D78914FAC6E00C2D128F5EF674F6DEB046E91B008079E7CD8994B25D1E7330EDB1ED1A05A64B06135BDBE39F4B06482AB4B8D1744D972DA34482C9B2C01A3D743F8AFAC78D5A77A6AE4A9B016B9C7597795EB1754EFF259A02')
        return Tlv_head('05 48', self.pack.get_bytes())

    def T10A(self, T0A: bytes):
        return Tlv_head('01 0A', T0A)

    def T143(self, T143: bytes):
        return Tlv_head('01 43', T143)



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader



class single_feed(IJceStruct):
    feed_attach_info: str = ""
    feed_info: str = ""
    feeds_update_time: int = 0
    feedskey: str = ""
    iUnifyRecomType: int = 0
    patch_singlefeed: dict[int, bytes] = None
    pullAll: bool = False
    recomfeeds: list[dict[int, bytes]] = None
    singlefeed: dict = None
    status: int = 0
    time: int = 0
    uContainerSubType: int = 0

    def read_from(self, reader: JceReader) -> None:
        self.singlefeed = reader.read_map(0)
        self.status = reader.read_any(1)
        self.feed_info = reader.read_string(2)
        self.feed_attach_info = reader.read_string(3)
        self.feedskey = reader.read_string(4)
        self.time = reader.read_any(5)
        self.recomfeeds = reader.read_any(6)
        self.uContainerSubType = reader.read_any(7)
        self.patch_singlefeed = reader.read_any(8)
        self.feeds_update_time = reader.read_any(9)
        self.pullAll = reader.read_any(10)
        self.iUnifyRecomType = reader.read_any(11)



    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



# package QMF_PROTOCAL;
from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class QmfDownstream(IJceStruct):
    BizCode: int = None
    BusiBuff: bytes = None
    Extra: bytes = None
    Seq: int = None
    ServiceCmd: str = None
    Uin: int = None
    WnsCode: int = None

    def read_from(self, reader: JceReader):
        self.Seq = reader.read_any(0)
        self.Uin = reader.read_any(1)
        self.WnsCode = reader.read_any(2)
        self.BizCode = reader.read_any(3)
        self.ServiceCmd = reader.read_any(4)
        self.BusiBuff = reader.read_any(5)
        self.Extra = reader.read_any(6)


    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



import json

from Jce_b import JceWriter, JceReader

from AndroidQQ.struct import PackHead_QMF
from AndroidQQ.struct.NS_MOBILE_FEEDS import mobile_applist_req, mobile_applist_rsp
from AndroidQQ.struct.cooperation import createQmfUpstream, UnQmfDownstream
from AndroidQQ.struct.feedcomponent.model import JceCellData
from AndroidQQ.utils import to_serializable


def SQQzoneSvc_shuoshuo(info, Uin: int):
    """
        获取说说列表
            :param info
            :param Uin 目标账号
            :return:

    """
    mapEx = {
        'mobile_detail_info': 'V1916A&9&28&4&2'
    }
    int64 = JceWriter().write_int64(int(info.uin), 0).bytes()

    applist_req = mobile_applist_req(
        uin=Uin,
        appid=311,
        count=10,
        attach_info='',
        album_show_type=0,
        refresh_type=1,
        extrance_type=0,
        mapEx=mapEx,
    ).to_bytes()
    Buffer = JceWriter().write_jce_struct(applist_req, 0)
    Buffer = JceWriter().write_map({'shuoshuo': {
        'NS_MOBILE_FEEDS.mobile_applist_req': Buffer
    }, 'hostuin': {'int64': int64}}, 0)

    Upstream = createQmfUpstream(info, 1, Buffer, 'QzoneNewService.applist.shuoshuo')
    Buffer = PackHead_QMF(info, 'SQQzoneSvc.shuoshuo', Upstream)

    return Buffer


def SQQzoneSvc_shuoshuo_rsp(Buffer: bytes, fullText: bool):
    def _human_reading():
        """
            人类可阅读
        """
        rsp = {}
        shuoshuo_list = []
        for item in applist_rsp.all_applist_data:
            CellDat = JceCellData(item.singlefeed)

            shuoshuo_list.append({'busi_param': CellDat.cell_operation.busi_param})

        rsp.update({'shuoshuo_list': shuoshuo_list})
        return rsp

    rsp_Buffer, msg, ret = UnQmfDownstream(Buffer, 'shuoshuo', 'NS_MOBILE_FEEDS.mobile_applist_rsp')

    if rsp_Buffer == b'':
        return {'Busi': {}, 'msg': msg, 'ret': ret}
    applist_rsp = JceReader(rsp_Buffer).read_object(mobile_applist_rsp)

    if fullText:
        # 全文返回
        return {'Busi': to_serializable(applist_rsp), 'msg': msg, 'ret': ret}
    else:
        return {'Busi': _human_reading(), 'msg': msg, 'ret': ret}



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: AndroidQQ/im/oidb/cmd0x922/cmd0x922.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from AndroidQQ.im.oidb.cmd0x922 import PushInfo_pb2 as AndroidQQ_dot_im_dot_oidb_dot_cmd0x922_dot_PushInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)AndroidQQ/im/oidb/cmd0x922/cmd0x922.proto\x12\x10im.oidb.cmd0x922\x1a)AndroidQQ/im/oidb/cmd0x922/PushInfo.proto\"\x1c\n\x07ReqBody\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\"\x80\x01\n\x07RspBody\x12\x18\n\x10need_update_flag\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12\x31\n\rmsg_push_info\x18\x03 \x01(\x0b\x32\x1a.im.oidb.cmd0x922.PushInfo\x12\x15\n\rnext_req_time\x18\x04 \x01(\r')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'AndroidQQ.im.oidb.cmd0x922.cmd0x922_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_REQBODY']._serialized_start=106
  _globals['_REQBODY']._serialized_end=134
  _globals['_RSPBODY']._serialized_start=137
  _globals['_RSPBODY']._serialized_end=265
# @@protoc_insertion_point(module_scope)



# struct com.tencent.msf.service.protocol.push;
from typing import Optional, Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class SvcRespRegister(IJceStruct):
    # 类变量的静态缓存
    # cache_bytes_0x769_rspbody = bytes([0])
    # cache_vecCustomStatus = bytes([0])
    bCrashFlag: bool = False
    bLargeSeqUpdate: bool = False
    bLogQQ: bool = False
    bNeedKik: bool = False
    bUpdateFlag: bool = False
    bytes_0x769_rspbody: Optional[bytes] = None
    cReplyCode: int = 0
    iClientPort: int = 0
    iHelloInterval: int = 300
    iLargeSeq: int = 0
    iStatus: int = 0
    lBid: int = 0
    lServerTime: int = 0
    lUin: int = 0
    strClientIP: str = ""
    strResult: str = ""
    timeStamp: int = 0
    uClientAutoStatusInterval: int = 600
    uClientBatteryGetInterval: int = 86400
    uExtOnlineStatus: int = 0
    vecCustomStatus: Optional[bytes] = None

    def read_from(self, reader: JceReader) -> None:
        self.lUin = reader.read_any(0)
        self.lBid = reader.read_any(1)
        self.cReplyCode = reader.read_any(2)
        self.strResult = reader.read_any(3)
        self.lServerTime = reader.read_any(4)
        self.bLogQQ = reader.read_any(5)
        self.bNeedKik = reader.read_any(6)
        self.bUpdateFlag = reader.read_any(7)
        self.timeStamp = reader.read_any(8)
        self.bCrashFlag = reader.read_any(9)
        self.strClientIP = reader.read_any(10)
        self.iClientPort = reader.read_any(11)
        self.iHelloInterval = reader.read_any(12)
        self.iLargeSeq = reader.read_any(13)
        self.bLargeSeqUpdate = reader.read_any(14)
        self.bytes_0x769_rspbody = reader.read_any(15)
        self.iStatus = reader.read_any(16)
        self.uExtOnlineStatus = reader.read_any(17)
        self.uClientBatteryGetInterval = reader.read_any(18)
        self.uClientAutoStatusInterval = reader.read_any(19)
        self.vecCustomStatus = reader.read_any(21)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass

    def to_dict(self) -> dict:
        return self.__dict__



from typing import Union

from Jce_b import IJceStruct
from Jce_b.typing import JceReader


class s_user(IJceStruct):
    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass




from typing import Union

from Jce_b import IJceStruct, JceWriter, JceReader
from .Source import Source
from ..NS_MOBILE_COMM import UgcRightInfo


class OperationPublishmoodReq(IJceStruct):
    busi_param: dict = None
    clientkey: str = ""
    content: str = ""
    extend_info: dict = None
    frames: int = 0
    hidden_poi: IJceStruct = None
    isWinPhone: int = 0
    issynctoweibo: bool = True
    isverified: bool = True
    lbsinfo: IJceStruct = None
    lock_days: int = 0
    mediaSubType: int = 0
    mediabittype: int = 0
    mediainfo: IJceStruct = None
    mediatype: int = 0
    modifyflag: int = 0
    open_appid: str = ""
    proto_extend_info: dict = None
    publishTime: int = 0
    richtype: str = ""
    richval: str = ""
    right_info: UgcRightInfo = None
    seal_id: int = 0
    shootInfo: IJceStruct = None
    source: Source = None
    sourceName: str = ""
    srcid: str = ""
    stored_extend_info: dict = None
    uin: int = 0
    weibourl: str = ""

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.uin, 0)
        if self.content:
            Jce.write_string(self.content, 1)

        Jce.write_object(self.isverified, 2)
        Jce.write_object(self.issynctoweibo, 3)
        if self.weibourl:
            Jce.write_object(self.weibourl, 4)
        Jce.write_object(self.mediatype, 5)
        #
        Jce.write_jce_struct(b'', 6)  # mediaInfo 暂时不处理

        if self.lbsinfo:
            Jce.write_object(self.lbsinfo, 7)

        # print(self.source)
        if self.source:
            Jce.write_jce_struct(self.source.to_bytes(), 8)
        Jce.write_object(self.mediabittype, 9)
        if self.busi_param:
            Jce.write_map(self.busi_param, 10)

        if self.clientkey:
            Jce.write_string(self.clientkey, 11)
        #

        Jce.write_string(self.open_appid, 12)
        #
        if self.right_info:
            Jce.write_jce_struct(self.right_info.to_bytes(), 13)
        Jce.write_jce_struct(bytes.fromhex('0a 3c 56 00 6c 76 00 8c 9c ac 0b 1c '), 14)  # 拍摄信息

        Jce.write_object(self.publishTime, 15)
        Jce.write_object(self.mediaSubType, 16)
        Jce.write_string(self.srcid, 17)

        Jce.write_object(self.modifyflag, 18)
        if self.extend_info:
            Jce.write_map(self.extend_info, 19)
        Jce.write_object(self.richtype, 20)
        Jce.write_object(self.richval, 21)
        Jce.write_object(self.isWinPhone, 22)
        Jce.write_object(self.sourceName, 23)
        if self.hidden_poi:
            Jce.write_object(self.hidden_poi, 24)
        Jce.write_object(self.seal_id, 25)
        Jce.write_object(self.frames, 26)
        Jce.write_object(self.lock_days, 27)
        if self.stored_extend_info:
            Jce.write_object(self.stored_extend_info, 28)
        if self.proto_extend_info:
            Jce.write_map(self.proto_extend_info, 29)
        return Jce.bytes()



from .MQUpdateSvc_com_qq_ti_web_scanlogin import *
from .OidbSvc_0xc96 import *
from .OidbSvc_0xc05 import *
from .OidbSvc_0xeb8 import *
from .OidbSvc_0x88d_1 import *
from .Heartbeat_Alive import *
from .StatSvc_register import *

from AndroidQQ.pack.SQQzoneSvc.like import *
from .MQUpdateSvc_com_qq_vip_zb_web_OidbSvc_0xdfa_0 import *
from .trpc_metaverse_mob_proxy_svr_MobProxy_SsoHandle import *
from .OidbSvcTrpcTcp_0xfe1_2 import *



from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader

from AndroidQQ.struct.SummaryCard import UserLocaleInfo


class ReqSummaryCard(IJceStruct):
    IsFriend: bool = False  # 是朋友
    ReqCommLabel: bool = False  # 是否请求通讯录标签
    ReqExtendCard: bool = False  # 是否请求扩展名片
    ReqMedalWallInfo: bool = False  # 请求勋章墙信息
    ReqNearbyGodInfo: bool = False  # 请求附近God信息
    AddFriendSource: int = 0  # 添加好友来源

    ComeFrom: int = 65535  # 来自
    GetControl: int = 0  # 获取控制
    GroupCode: int = 0  # 群号
    GroupUin: int = 0  # 群 Uin
    TinyId: int = 0  # TinyId
    Uin: int = 0  # Uin
    stLocaleInfo: UserLocaleInfo = None
    SearchName: str = ''  # 搜索名称
    LikeSource: int = 0  # 喜欢来源
    QzoneFeedTimestamp: int = 0  # Qzone Feed时间戳
    RichCardNameVer: int = 0  # 丰富的卡名

    ReqKandianInfo: bool = False  # 是否请求看点
    ReqLastGameInfo: bytes = b''  # 请求上次游戏信息
    ReqStarInfo: bytes = b''  # 请求星星信息
    ReqTemplateInfo: bytes = b''  # Req Template Info
    SecureSig: bytes = b''  # 安全的签名
    Seed: bytes = b''  # 发送?

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        jce = JceWriter()
        jce.write_int64(self.Uin, 0)
        jce.write_int64(self.ComeFrom, 1)
        jce.write_int64(self.QzoneFeedTimestamp, 2)
        jce.write_bool(self.IsFriend, 3)
        jce.write_int64(self.GroupCode, 4)
        jce.write_int64(self.GroupUin, 5)
        if self.Seed != b'':
            jce.write_bytes(self.Seed, 6)

        if self.SearchName != '':
            jce.write_string(self.SearchName, 7)

        jce.write_int64(self.GetControl, 8)
        jce.write_int64(self.AddFriendSource, 9)

        if self.SecureSig != b'':
            jce.write_bytes(self.SecureSig, 10)

        if self.ReqLastGameInfo != b'':
            jce.write_bytes(self.ReqLastGameInfo, 11)

        if self.ReqTemplateInfo != b'':
            jce.write_bytes(self.ReqTemplateInfo, 12)

        if self.ReqStarInfo != b'':
            jce.write_bytes(self.ReqStarInfo, 13)

        # 14 暂时不处理

        jce.write_int64(self.TinyId, 15)
        jce.write_int64(self.LikeSource, 16)
        if self.stLocaleInfo:
            jce.write_jce_struct(self.stLocaleInfo.to_bytes(), 17)

        jce.write_bool(self.ReqMedalWallInfo, 18)

        # 19 暂时不处理
        jce.write_bool(self.ReqNearbyGodInfo, 20)
        jce.write_bool(self.ReqCommLabel, 21)
        jce.write_bool(self.ReqExtendCard, 22)

        if self.ReqKandianInfo:
            jce.write_bool(self.ReqKandianInfo, 23)

        jce.write_int64(self.RichCardNameVer, 24)

        return jce.bytes()



# struct com.tencent.msf.service.protocol.push;
from typing import Union, List

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class SvcReqRegister(IJceStruct):
    # 类型注解
    bIsOnline: bool = False  # 是否在线
    bIsSetStatus: bool = False  # 是否设置状态
    bIsShowOnline: bool = False  # 是否显示在线
    bKikPC: bool = False  # 是否强网
    bKikWeak: bool = False  # 是否弱网
    bOnlinePush: bool = True  # 是否在线推送
    bOpenPush: bool = True
    bRegType: bool = False
    bSetMute: bool = False  # 设置沉默
    bSlientPush: bool = False
    bTimActiveFlag: bool = True
    # bytes_0x769_reqbody: Optional[bytes] = None
    cBindUinNotifySwitch: int = 1
    cConnType: int = 0
    cNetType: int = 0
    cNotifySwitch: int = 1
    iBatteryStatus: int = 0
    iLargeSeq: int = 0
    iLastWatchStartTime: int = 0
    iLocaleID: int = 2052
    iOSVersion: int = 0
    iStatus: int = 11  # 我的状态
    lBid: int = 0
    lCpId: int = 0
    lUin: int = 0
    lVendorDevId: int = 0
    sBuildVer: str = ""
    sChannelNo: str = ""
    sOther: str = ""
    # stVendorPushInfo: Optional['VendorPushInfo'] = None  # Assuming 'VendorPushInfo' is a class defined elsewhere
    strDevName: str = ""
    strDevType: str = ""
    strIOSIdfa: str = ""
    strOSVer: str = ""
    strVendorName: str = ""
    strVendorOSName: str = ""
    timeStamp: int = 0
    uExtOnlineStatus: int = 0
    uNewSSOIp: int = 0
    uOldSSOIp: int = 0

    vecBindUin: List[int] = None
    vecCustomStatus: bytes = None
    vecDevParam: bytes = None
    vecGuid: bytes = None
    vecServerBuf: bytes = None

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        jce = JceWriter()
        jce.write_object(self.lUin, 0)
        jce.write_object(self.lBid, 1)
        jce.write_object(self.cConnType, 2)
        jce.write_object(self.sOther, 3)
        jce.write_object(self.iStatus, 4)
        jce.write_object(self.bOnlinePush, 5)
        jce.write_object(self.bIsOnline, 6)
        jce.write_object(self.bIsSetStatus, 7)
        jce.write_object(self.bKikPC, 8)
        jce.write_object(self.bKikWeak, 9)
        jce.write_object(self.timeStamp, 10)
        jce.write_object(self.iOSVersion, 11)
        jce.write_object(self.cNetType, 12)

        if self.sBuildVer is not None:
            jce.write_object(self.sBuildVer, 13)

        jce.write_object(self.bRegType, 14)

        if self.vecDevParam is not None:
            jce.write_object(self.vecDevParam, 15)

        if self.vecGuid is not None:
            jce.write_object(self.vecGuid, 16)

        jce.write_object(self.iLocaleID, 17)
        jce.write_object(self.bSlientPush, 18)

        if self.strDevName != '':
            jce.write_object(self.strDevName, 19)

        if self.strDevType != '':
            jce.write_object(self.strDevType, 20)

        if self.strOSVer != '':
            jce.write_object(self.strOSVer, 21)

        jce.write_object(self.bOnlinePush, 22)
        jce.write_object(self.iLargeSeq, 23)
        jce.write_object(self.iLastWatchStartTime, 24)

        if self.vecBindUin is not None:
            jce.write_object(self.vecBindUin, 25)

        jce.write_object(self.uOldSSOIp, 26)

        jce.write_object(self.uNewSSOIp, 27)

        if self.sChannelNo != '':
            jce.write_object(self.sChannelNo, 28)

        jce.write_object(self.lCpId, 29)
        # 后面懒地传了

        return jce.bytes()



import random
import socket
import select

import threading
import time

import socks
from AndTools import pack_u, pack_b

from AndroidQQ import log
from AndroidQQ.utils.sso_server import get_sso_list

clients = []
client_info = {}
lock = threading.Lock()

ip_address = ''
ip_list = {}


def repackage(data, client):
    """重组包体"""
    global client_info

    with lock:
        if client in client_info and not client._closed:
            client_info[client]['data'] = client_info[client]['data'] + data
        else:
            print(f"Socket {client} 已关闭或不存在")
            return

    pack_ = pack_u(client_info[client]['data'])
    while True:
        if pack_.get_len() <= 4:
            """小于4个字节直接跳出"""
            break
        _len = pack_.get_int()

        if _len <= pack_.get_len() + 4:
            _bin = pack_.get_bin(_len - 4)
            _func = client_info[client]['func']
            _func(_bin)
            with lock:
                if client in client_info:
                    # 安全地访问字典
                    client_info[client]['data'] = pack_.get_all()
                else:
                    log.error(f"尝试在已关闭的套接字中写入数据: {client}")

        else:
            pack = pack_b()
            pack.add_int(_len)
            pack.add_bin(pack_.get_all())
            pack_ = pack_u(pack.get_bytes())
            break


def disconnect_client(client):
    global clients, client_info, lock

    with lock:
        if client in clients:
            clients.remove(client)
            client_info.pop(client, None)
            client.close()

    return {'clients': len(clients), 'client_info': len(client_info)}


def receive_data_all():
    """在一个独立的线程中,接收并处理全部连接的数据"""
    global clients, client_info, lock

    while True:
        time.sleep(0.1)
        with lock:
            if len(clients) == 0:
                continue
            # 由于select可能会修改列表，所以使用clients[:]创建一个副本进行迭代
            readable, _, _ = select.select(clients[:], [], [], 0)

        for client in readable:
            try:
                data = client.recv(1024)
                if data:
                    repackage(data, client)
                else:
                    disconnect_client(client)
            except ConnectionResetError as e:
                log.error(f"连接重置错误: {e}")
                disconnect_client(client)
            except OSError as e:
                if e.errno == 9:  # Bad file descriptor
                    log.error(f"尝试操作已关闭的套接字: {e}")
                else:
                    log.error(f"OS错误: {e}")
                disconnect_client(client)

            # if not data:
            #     disconnect_client(client, clients, client_info)
            #     log.info('断开连接')
            # else:
            #     # log.info(f"从客户端收到的数据: {data.hex()}")
            #     repackage(data, client)


def start_client(_func=None, proxy=None):
    global ip_list

    if proxy is None:
        proxy = []
    if ip_list:
        random_item = random.choice(ip_list)
        host = random_item['1']
        port = random_item['2']
    else:
        # 没初始化ip列表前用这个快速连接
        ip_list = get_sso_list()
        random_item = random.choice(ip_list)
        host = random_item['1']
        port = random_item['2']

    client = socks.socksocket()

    if len(proxy) >= 2:
        # 对于需要设置代理的客户端，创建一个配置了代理的socket对象

        if len(proxy) == 2:
            client.set_proxy(socks.SOCKS5, proxy[0], proxy[1])
        else:
            client.set_proxy(socks.SOCKS5, proxy[0], int(proxy[1]), username=proxy[2], password=proxy[3])

    try:
        client.connect((host, port))
    except socket.error as e:
        log.info(f"连接到 {host}:{port} 失败，错误信息: {e}")
        return None

    with lock:
        client_info[client] = {'data': b'', 'func': _func}
        clients.append(client)
    return client


def get_ip_list():
    time.sleep(1)  # 超过一秒再去请求,防止测试时请求
    global ip_list
    ip_list = get_sso_list()
    # print(ip_list)


def start_tcp_service():
    """启动TCP服务"""
    threading.Thread(target=receive_data_all, daemon=True).start()

    # threading.Thread(target=get_ip_list, daemon=True).start()
    log.info('启动接收线程')


start_tcp_service()

if __name__ == "__main__":
    ip_list = get_sso_list()
    print(ip_list)
    pass



import base64


def to_serializable(obj):
    # Jce解析需要递归解析

    if isinstance(obj, bytearray):
        return obj.hex()
    if isinstance(obj, dict):
        return {key: to_serializable(value) for key, value in obj.items()}
    elif isinstance(obj, list):
        return [to_serializable(element) for element in obj]
    elif hasattr(obj, '__dict__'):
        return {key: to_serializable(value) for key, value in obj.__dict__.items()}
    else:
        return obj  # 基本类型


def qq_bkn(_skey: str):
    base = 5381
    for char in _skey:
        base += (base << 5) + ord(char)
    result = base & 2147483647
    return str(result)


if __name__ == '__main__':
    skey = "MspAxHssKk"
    print(qq_bkn(skey))



from loguru import logger

from AndroidQQ.struct import PackHeadNoToken, Pack_


def Heartbeat_Alive(info):
    """快速网络检测Heartbeat """
    # todo 暂未完成
    buffer = PackHeadNoToken(info, b'', 'Heartbeat.Alive')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer


def Heartbeat_Alive_rsp(Buffer: bytes):
    logger.info(Buffer.hex())



from typing import Union

from Jce_b import IJceStruct, JceWriter
from Jce_b.typing import JceReader


class UgcRightInfo(IJceStruct):
    ugc_right: int = 0

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.ugc_right, 0)
        return Jce.bytes()



from AndTools import pack_u
from pydantic import BaseModel

from AndroidQQ import log


def filter_none(data):
    if isinstance(data, dict):
        new_dict = {}
        for k, v in data.items():
            if v is not None and v != '' and v != b'':
                if isinstance(v, dict) or isinstance(v, list):
                    v = filter_none(v)
                new_dict[k] = v
        return new_dict
    elif isinstance(data, list):
        new_list = []
        for item in data:
            if item is not None and item != '' and item != b'':
                if isinstance(item, dict) or isinstance(item, list):
                    item = filter_none(item)
                new_list.append(item)
        return new_list
    return data


def Un_T146(_data):
    _data = _data[4:]
    pack = pack_u(_data)
    _len = pack.get_short()
    title = pack.get_bin(_len)
    _len = pack.get_short()
    message = pack.get_bin(_len)
    return {'title': title.decode(), 'message': message.decode()}


def Un_T512(Buffer: bytes):
    pack = pack_u(Buffer)
    count = pack.get_short()
    p_skey_list = {}
    for i in range(count):
        len = pack.get_short()
        name = pack.get_bin(len)
        len = pack.get_short()
        P_skey = pack.get_bin(len)
        pack.get_short()
        p_skey_list.update({name.decode('utf-8'): P_skey.decode('utf-8')})
    return p_skey_list


class Un_Tlv:

    def __init__(self, data, info):
        self.info = info
        self.pack = pack_u(data)
        self.auth_info = {}
        self.handler_map = {
            '011a': lambda _data: setattr(self.info, 'uin_name', _data[5:].decode('utf-8')),
            '0120': lambda _data: setattr(self.info.cookies, 'skey', _data.decode('utf-8')),
            '0103': lambda _data: setattr(self.info.cookies, 'client_key', _data.hex()),
            '0004': lambda _data: setattr(self.info, 'uin', _data[4:].decode('utf-8')),
            '001e': lambda _data: setattr(self.info, 'key_rand', _data),  # 手表扫码返回的时候必须
            '0018': lambda _data: setattr(self.info.UN_Tlv_list, 'T018', _data),
            '0019': lambda _data: setattr(self.info.UN_Tlv_list, 'T019', _data),
            '0065': lambda _data: setattr(self.info.UN_Tlv_list, 'T065', _data),
            '0108': lambda _data: setattr(self.info.UN_Tlv_list, 'T108', _data),
            '010e': lambda _data: setattr(self.info.UN_Tlv_list, 'userSt_Key', _data),
            '0134': lambda _data: setattr(self.info.UN_Tlv_list, 'wtSessionTicketKey', _data),
            '0114': lambda _data: setattr(self.info.UN_Tlv_list, 'userStSig', _data),
            '0133': lambda _data: setattr(self.info.UN_Tlv_list, 'wtSessionTicket', _data),
            '016a': lambda _data: setattr(self.info.UN_Tlv_list, 'T16A', _data),
            '0106': lambda _data: setattr(self.info.UN_Tlv_list, 'T106', _data),
            '0143': lambda _data: setattr(self.info.UN_Tlv_list, 'D2_T143', _data),
            '010a': lambda _data: setattr(self.info.UN_Tlv_list, 'TGT_T10A', _data),
            '0146': lambda _data: setattr(self.info.UN_Tlv_list, 'T146', Un_T146(_data)),
            '0192': lambda _data: setattr(self.info.UN_Tlv_list, 'T192_captcha', _data.decode('utf-8')),
            '0104': lambda _data: setattr(self.info.UN_Tlv_list, 'T104_captcha', _data),
            '0546': lambda _data: setattr(self.info.UN_Tlv_list, 'T546_captcha', _data),
            '0512': lambda _data: setattr(self.info.cookies, 'p_skey', Un_T512(_data)),

            '0003': lambda _data: self.auth_info.__setitem__('0003', _data.decode('utf-8')),
            '0005': lambda _data: self.auth_info.__setitem__('0005', _data.decode('utf-8')),
            '0036': lambda _data: self.auth_info.__setitem__('0036', _data.decode('utf-8')),
            '0305': lambda _data: setattr(self.info, 'share_key', _data)

        }

    def _content(self, head, data):
        handler = self.handler_map.get(head)
        if handler:
            handler(data)
        else:
            # print('tlv未解析', head, data.hex())
            pass

    def get_auth_result(self):
        return self.auth_info

    def return_specified_content(self):
        data = {
            'uin_name': self.info.uin_name,
            'guid': self.info.Guid.hex(),
            'token_A2': self.info.UN_Tlv_list.T143_token_A2,
            'token_A4': self.info.UN_Tlv_list.T10A_token_A4,
            'client_key': self.info.cookies.client_key,
        }
        return data

    def unpack(self):
        count = self.pack.get_short()
        for _ in range(count):
            head = self.pack.get_bin(2).hex()
            _len = self.pack.get_short()
            _data = self.pack.get_bin(_len)
            self._content(head, _data)
        return self.info



import json

from AndroidQQ.im.oidb.scanlogin import ScanLoginReq, ScanLoginRsp
from AndroidQQ.struct import PackHeadNoToken, Pack_


def web_scanlogin(info, service_type: int, token: str):
    """
        uint32_service_type int 4 扫码 5 确认登录
        bytes_token str

    """

    token = {
        'uint32_service_type': service_type,
        'bytes_token': token
    }
    scan_login_req = ScanLoginReq(
        service_type=0,
        token=json.dumps(token).encode('utf-8')
    )
    buffer = scan_login_req.SerializeToString()
    buffer = PackHeadNoToken(info, buffer, 'MQUpdateSvc_com_qq_ti.web.scanlogin')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer


def web_scanlogin_req(buffer):
    scan_login_rsp = ScanLoginRsp()
    scan_login_rsp.ParseFromString(buffer)
    return scan_login_rsp.field4.decode()



import json
import re

import requests
from AndroidQQ.utils import qq_bkn
from bs4 import BeautifulSoup

from AndroidQQ import log

from .headers import *


def qq_level_index(info, cookie: str):
    """获取QQ等级的具体信息 多了需要代理"""
    try:
        response = requests.get(
            url="https://ti.qq.com/qqlevel/index",
            params={
                "_wv": "3",
                "_wwv": "1",
                "tab": "3",
                "source": "26",
            },
            headers={
                "Host": "ti.qq.com",
                "Connection": "keep-alive",
                "Upgrade-Insecure-Requests": "1",
                "User-Agent": User_Agent,
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,"
                          "*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "X-Requested-With": "com.tencent.mobileqq",
                "Sec-Fetch-Site": "none",
                "Sec-Fetch-Mode": "navigate",
                "Sec-Fetch-User": "?1",
                "Sec-Fetch-Dest": "document",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": cookie,
            },
            proxies=info.proxy_proxies
        )
        soup = BeautifulSoup(response.content, 'html.parser')
        scripts = soup.find_all('script')
        data_string = None
        for script in scripts:
            if script.string and '__INITIAL_STATE__' in script.string:
                data_string = script.string
                break

        # 提取JavaScript对象

        json_data = re.search(r'window\.__INITIAL_STATE__\s*=\s*({.*?});', data_string).group(1)
        json_data = json.loads(json_data)
        return json_data

    except requests.exceptions.RequestException:
        log.error('HTTP 请求失败')
        return {}


def GetLevelTask(info, cookie):
    """获取任务,具有更新效果"""

    try:
        rsp = requests.post(

            url="https://ti.qq.com/qqlevel/trpc/levelTask/Get",
            params={
                "bkn": qq_bkn(info.cookies.skey),
            },

            json={
                "mode": 7
            },

            headers={
                "Host": "ti.qq.com",
                "Connection": "keep-alive",
                "Upgrade-Insecure-Requests": "1",
                "User-Agent": User_Agent,
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,"
                          "*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "X-Requested-With": "com.tencent.mobileqq",
                "Sec-Fetch-Site": "none",
                "Sec-Fetch-Mode": "navigate",
                "Sec-Fetch-User": "?1",
                "Sec-Fetch-Dest": "document",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": cookie,
            },
            proxies=info.proxy_proxies
        )
        return rsp.json()
    except Exception as e:
        log.error(f'获取等级任务列表失败{e}')
        return {}


def RefreshTask(info, cookie, task_id: str):
    """刷新任务"""
    try:
        rsp = requests.post(
            url="https://ti.qq.com/qqlevel/trpc/levelTask/Refresh",
            params={
                "bkn": qq_bkn(info.cookies.skey),
            },
            json={
                "task_id": task_id,
                "mode": 7

            },

            headers={
                "Host": "ti.qq.com",
                "Connection": "keep-alive",
                "Upgrade-Insecure-Requests": "1",
                "User-Agent": User_Agent,
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,"
                          "*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "X-Requested-With": "com.tencent.mobileqq",
                "Sec-Fetch-Site": "none",
                "Sec-Fetch-Mode": "navigate",
                "Sec-Fetch-User": "?1",
                "Sec-Fetch-Dest": "document",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": cookie,
            },
            proxies=info.proxy_proxies

        )
        return rsp.json()
    except Exception as e:
        log.info(f'刷新任务失败{e}')
        return {}


def format_conversion(data_json):
    """转换任务格式"""
    response = data_json.get('response')
    base_task_list = response.get('base_info', {}).get('base_task_list', [])
    extra_task_list = response.get('extra_info', {}).get('extra_task_list', [])
    base_task_list.extend(extra_task_list)
    task_list = {}
    done_count = 0
    for row in base_task_list:
        title = row['title']
        task_list[title] = {}
        task_list[title]['button_text'] = row['button_text']
        task_list[title]['is_done'] = row['is_done']
        task_list[title]['task_id'] = row['task_id']

        if row['is_done']:
            done_count = done_count + 1

    task_list['done_count'] = done_count

    keys_to_delete = [
        '会员极速星二阶专享',
        '会员极速星三阶专享',
        '会员极速星专享',
        '大会员-Thunder开通用户专享',
        'SVIP-STAR开通用户专享',
        'SVIP10三星+豪华黄钻LV10至尊版专享',
        'QQ大会员超级包月身份专享',
        'QQ大会员连续包月特权专享',
        '邀请好友助力',
        'SVIP连续包月特权',
        '电脑QQ在线',
        '参加龙王令活动获取加速天数',
        'SVIP连续包月特权',
    ]
    for key in keys_to_delete:
        task_list.pop(key, None)
    return task_list


def GetLevelStatus(info, cookie, query: bool = False):
    try:

        rsp = requests.post(
            url='https://ti.qq.com/qqlevel/trpc/levelTaskCenter/GetLevelStatus?bkn=' + qq_bkn(info.cookies.skey),
            headers={
                "Host": "ti.qq.com",
                "Connection": "keep-alive",
                "Upgrade-Insecure-Requests": "1",
                "User-Agent": User_Agent,
                "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,image/avif,image/webp,image/apng,"
                          "*/*;q=0.8,application/signed-exchange;v=b3;q=0.9",
                "X-Requested-With": "com.tencent.mobileqq",
                "Sec-Fetch-Site": "none",
                "Sec-Fetch-Mode": "navigate",
                "Sec-Fetch-User": "?1",
                "Sec-Fetch-Dest": "document",
                "Accept-Encoding": "gzip, deflate",
                "Accept-Language": "zh-CN,zh;q=0.9,en-US;q=0.8,en;q=0.7",
                "Cookie": cookie,
            },
            proxies=info.proxy_proxies

        )
        return format_conversion(rsp.json()) if query else rsp.json().get('response', {})
    except Exception as e:
        log.error(f'获取等级任务列表失败{e}')
        return {}


if __name__ == '__main__':
    # print(qq_level_index())
    pass



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: IM_r.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nIM_r.proto\"\x95\x02\n\x0eOidbSvc0x88d1r\x12\n\n\x02\x66\x31\x18\x01 \x01(\x05\x12\n\n\x02\x66\x32\x18\x02 \x01(\x05\x12\n\n\x02\x66\x33\x18\x03 \x01(\x05\x12\"\n\x02\x66\x34\x18\x04 \x01(\x0b\x32\x16.OidbSvc0x88d1r.Field4\x1a\xba\x01\n\x06\x46ield4\x12*\n\x02\x66\x31\x18\x01 \x01(\x0b\x32\x1e.OidbSvc0x88d1r.Field4.Field41\x1a\x83\x01\n\x07\x46ield41\x12\r\n\x05group\x18\x01 \x01(\x05\x12\n\n\x02\x66\x32\x18\x02 \x01(\x05\x12\x33\n\x02\x66\x33\x18\x03 \x01(\x0b\x32\'.OidbSvc0x88d1r.Field4.Field41.Field413\x1a(\n\x08\x46ield413\x12\x0c\n\x04type\x18\x07 \x01(\x05\x12\x0e\n\x06prompt\x18\x18 \x01(\t\"\xbf\x03\n\rOidbSvc0xeb8r\x12\x0b\n\x03src\x18\x01 \x01(\x05\x12\x11\n\tproto_ver\x18\x02 \x01(\x05\x12\x0f\n\x07\x66ield_3\x18\x03 \x01(\x05\x12(\n\x08Rsp_Body\x18\x04 \x01(\x0b\x32\x16.OidbSvc0xeb8r.RspBody\x1a\xd2\x02\n\x07RspBody\x12\x14\n\x0c\x63heck_result\x18\x01 \x01(\x05\x12\x34\n\nphone_info\x18\x02 \x03(\x0b\x32 .OidbSvc0xeb8r.RspBody.PhoneInfo\x12\x18\n\x10mibao_change_url\x18\x04 \x01(\t\x12\x18\n\x10mibao_verify_url\x18\x05 \x01(\t\x12\x1b\n\x13verify_premibao_url\x18\x06 \x01(\t\x12\x15\n\rhori_bar_tips\x18\x07 \x01(\t\x12\x14\n\x0cred_dot_tips\x18\x08 \x01(\t\x12\x0e\n\x06is_IOT\x18\t \x01(\x08\x1am\n\tPhoneInfo\x12\x12\n\nphone_type\x18\x01 \x01(\x05\x12\x14\n\x0c\x63ountry_code\x18\x02 \x01(\t\x12\r\n\x05phone\x18\x03 \x01(\t\x12\x14\n\x0cphone_status\x18\x04 \x01(\x05\x12\x11\n\tvas_phone\x18\x05 \x01(\x0c\"\xf2\x02\n\rOidbSvc0xc05r\x12\x0b\n\x03src\x18\x01 \x01(\x05\x12\x11\n\tproto_ver\x18\x02 \x01(\x05\x12\x0f\n\x07\x66ield_3\x18\x03 \x01(\x05\x12(\n\x08Rsp_Body\x18\x04 \x01(\x0b\x32\x16.OidbSvc0xc05r.RspBody\x1a\xba\x01\n\nAppListRsp\x12\x13\n\x0btotal_count\x18\x01 \x01(\x05\x12\x35\n\tapp_infos\x18\x02 \x03(\x0b\x32\".OidbSvc0xc05r.AppListRsp.appinfos\x12\r\n\x05limit\x18\x03 \x01(\x05\x1aQ\n\x08\x61ppinfos\x12\r\n\x05\x61ppid\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04logo\x18\t \x01(\t\x12\x0c\n\x04time\x18\x1a \x01(\x05\x1aI\n\x07RspBody\x12\x0f\n\x07wording\x18\x01 \x01(\t\x12-\n\nAppListRsp\x18\x0b \x01(\x0b\x32\x19.OidbSvc0xc05r.AppListRspb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'IM_r_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_OIDBSVC0X88D1R']._serialized_start=15
  _globals['_OIDBSVC0X88D1R']._serialized_end=292
  _globals['_OIDBSVC0X88D1R_FIELD4']._serialized_start=106
  _globals['_OIDBSVC0X88D1R_FIELD4']._serialized_end=292
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41']._serialized_start=161
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41']._serialized_end=292
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41_FIELD413']._serialized_start=252
  _globals['_OIDBSVC0X88D1R_FIELD4_FIELD41_FIELD413']._serialized_end=292
  _globals['_OIDBSVC0XEB8R']._serialized_start=295
  _globals['_OIDBSVC0XEB8R']._serialized_end=742
  _globals['_OIDBSVC0XEB8R_RSPBODY']._serialized_start=404
  _globals['_OIDBSVC0XEB8R_RSPBODY']._serialized_end=742
  _globals['_OIDBSVC0XEB8R_RSPBODY_PHONEINFO']._serialized_start=633
  _globals['_OIDBSVC0XEB8R_RSPBODY_PHONEINFO']._serialized_end=742
  _globals['_OIDBSVC0XC05R']._serialized_start=745
  _globals['_OIDBSVC0XC05R']._serialized_end=1115
  _globals['_OIDBSVC0XC05R_APPLISTRSP']._serialized_start=854
  _globals['_OIDBSVC0XC05R_APPLISTRSP']._serialized_end=1040
  _globals['_OIDBSVC0XC05R_APPLISTRSP_APPINFOS']._serialized_start=959
  _globals['_OIDBSVC0XC05R_APPLISTRSP_APPINFOS']._serialized_end=1040
  _globals['_OIDBSVC0XC05R_RSPBODY']._serialized_start=1042
  _globals['_OIDBSVC0XC05R_RSPBODY']._serialized_end=1115
# @@protoc_insertion_point(module_scope)



# struct com.tencent.mobileqq.troop.handler;
from google.protobuf.json_format import MessageToDict

from AndroidQQ.im.oidb.cmd0x88d.oidb_0x88d_pb2 import ReqGroupInfo, GroupInfo, ReqBody, RspBody
from AndroidQQ.im.oidb.oidb_sso import OIDBSSOPkg
from AndroidQQ.struct import Pack_Head, Pack_


def stgroupinfo():
    group_info = GroupInfo()
    group_info.group_class_ext = 0
    group_info.group_answer = ''
    return group_info


def OidbSvc_0x88d_1(info, group_code: int):
    group_info = GroupInfo(
        group_class_ext=0,
        group_answer=''
    )

    reqGroupInfo = ReqGroupInfo(
        group_code=group_code,
        stgroupinfo=group_info,

    )
    reqBody = ReqBody(
        appid=info.device.app_id,
        reqgroupinfo=[reqGroupInfo],
    )
    oIDBSSOPkg = OIDBSSOPkg(
        command=2189,
        service_type=1,  # 不等于 1 OidbSvc.0x88d_0
        bodybuffer=reqBody.SerializeToString(),
    )
    buffer = oIDBSSOPkg.SerializeToString()

    buffer = Pack_Head(info, buffer, 'OidbSvc.0x88d_1')
    buffer = Pack_(info, buffer, Types=8, encryption=1, token=True)
    return buffer


def OidbSvc_0x88d_1_rep(buffer):
    oIDBSSOPkg = OIDBSSOPkg()
    oIDBSSOPkg.ParseFromString(buffer)
    rep_body = RspBody()
    rep_body.ParseFromString(oIDBSSOPkg.bodybuffer)
    return MessageToDict(rep_body)


if __name__ == '__main__':
    pass



# 消息服务
from Jce import JceInputStream, JceStruct
from Jce_b import JceWriter

from AndroidQQ.struct import PackHeadNoToken, Pack_, Un_jce_Head, Un_jce_Head_2


def PullUnreadMsgCount(info):
    """拉取未读消息数"""
    jce = JceWriter()
    jce.write_int32(1, 0)
    jce.write_int32(1, 1)
    jce.write_int32(1, 2)
    _data = jce.bytes()
    _data = JceWriter().write_jce_struct(_data, 0)
    _data = JceWriter().write_map({'req_PullUnreadMsgCount': _data}, 0)
    _data = PackHeadNoToken(info, _data, 'MessageSvc.PullUnreadMsgCount', 'MessageSvc', 'PullUnreadMsgCount')
    _data = Pack_(info, _data, Types=11, encryption=1, sso_seq=info.seq)
    return _data


def PullUnreadMsgCount_res(data):
    """2=未读消息数"""
    data = Un_jce_Head(data)
    data = data[32:]  # 去掉头部
    jce = JceStruct()
    jce.read_from(JceInputStream(data))
    return jce.to_json()



import datetime
import random
from typing import Union

from AndTools import pack_u
from box import Box
from pydantic import BaseModel

import AndroidQQ.pack.friendlist as friendlist
import AndroidQQ.struct.OidbSvc as OidbSvc
import AndroidQQ.struct.StatSvc as StatSvc
import AndroidQQ.struct.wtlogin as wt_login
from AndroidQQ.Tcp import start_client, disconnect_client
from AndroidQQ.http import qq_level_index, WriteMindJar, change_psw_getsms, Friends, bot_uin, delete_qq_friend, \
    GetLevelStatus, GetLevelTask, RefreshTask, credit_score, GetHttpIp
from AndroidQQ.http.music import Music
from AndroidQQ.http.weishi import weishi_up_
from AndroidQQ.pack import *
from AndroidQQ.pack.MQUpdateSvc_com_qq_ti_web_scanlogin import *
from AndroidQQ.pack.SQQzoneSvc import SQQzoneSvc_shuoshuo, SQQzoneSvc_shuoshuo_rsp, SQQzoneSvc_publishmood, \
    SQQzoneSvc_publishmood_rsp, SQQzoneSvc_delUgc, SQQzoneSvc_delUgc_rsp
from AndroidQQ.pack.SummaryCard import SummaryCard_ReqSummaryCard, SummaryCard_ReqSummaryCard_rsp
from AndroidQQ.pack.test import avatar_test
from AndroidQQ.struct import MessageSvc
from AndroidQQ.struct.Avatarlnfo import GetAvatarInfo, GetAvatarInfo_res
from AndroidQQ.struct.QQService import SvcReqGetDevLoginInfo, GetDevLoginInfo_profile, GetDevLoginInfo_res
from AndroidQQ.struct.SummaryCard import ReqSummaryCard
from AndroidQQ.struct.head import *
from AndroidQQ.struct.push import SvcReqRegister
from AndroidQQ.utils import qq_bkn


class cookies(BaseModel):
    skey: str = None
    client_key: str = None
    p_skey: dict = {}


class device(BaseModel):
    # 软件信息
    version: str = None
    package_name: str = None  # com.tencent.qqlite
    Sig: str = None  # A6 B7 45 BF 24 A2 C2 77 52 77 16 F6 F3 6E B6 8D
    build_time: int = None  # 软件构建时间 1654570540
    sdk_version: str = None  # #6.0.0.2366
    client_type: str = None  # android
    app_id: int = None  # 似乎可以传空
    var: str = None

    # 设备信息
    name: str = 'android'
    internet: str = 'China Mobile GSM'
    internet_type: str = 'wifi'
    model: str = 'V1916A'
    brand: str = 'vivo'
    Mac_bytes: bytes = None  # '02:00:00:00:00:00'
    Bssid_bytes: bytes = None  # '00:14:bf:3a:8a:50'
    android_id: bytes = None  # 4cba299189224ca5 Android 操作系统中设备的一个唯一ID。每个设备在首次启动时都会生成一个随机的64位数字作为其
    boot_id: str = '65714910-7454-4d01-a148-6bdf337a3812'  # Linux系统中用来唯一标识系统自上次启动以来的运行时期的标识符
    Imei: str = None
    Mac: str = None  # 02:00:00:00:00:00
    Bssid: str = None  # 00:14:bf:3a:8a:50


class UN_Tlv_list(BaseModel):
    TGT_T10A: bytes = b''
    D2_T143: bytes = b''
    T100_qr_code_mark: bytes = b''  # watch
    T018: bytes = b''  # watch
    T019: bytes = b''  # watch
    T065: bytes = b''  # watch
    T108: bytes = b''
    userSt_Key: bytes = b''  # T10E
    wtSessionTicketKey: bytes = b''  # 134
    wtSessionTicket: bytes = b''  # 133

    userStSig: bytes = b''  # T114
    T16A: bytes = b''
    T106: bytes = b''
    T146: Union[str, dict] = None
    T192_captcha: str = None
    T104_captcha: bytes = b''
    T546_captcha: bytes = b''


#


class info_model(BaseModel):
    uin: str = '0'
    uin_name: str = None
    password: str = None
    seq: int = 5267
    share_key: bytes = None  # _D2Key
    key_rand: bytes = get_random_bin(16)
    key_tgtgt: bytes = None
    key_Pubkey: bytes = None  # 公钥
    Guid: bytes = get_random_bin(16)
    login_time: int = int(time.time())
    UN_Tlv_list: UN_Tlv_list = UN_Tlv_list()
    device: device = device()
    cookies: cookies = cookies()
    Tips: str = None
    proxy_str: str = None
    proxy_proxies: dict = None
    emp_time: str = None


class AndroidQQ:
    def __init__(self, **kwargs):
        """
        :param client_type: QQ or Watch
        :param kwargs:
        """

        self.info = info_model()
        self.proxy = kwargs.get('proxy', [])  # 元组[121.236.248.165,40033]
        if self.proxy:
            proxy_host = self.proxy[0]
            proxy_port = self.proxy[1]
            # 检查是否提供了用户名和密码
            proxy_user = self.proxy[2] if len(self.proxy) > 2 else None
            proxy_pass = self.proxy[3] if len(self.proxy) > 3 else None

            # 如果有用户名和密码，则在代理字符串中包含这些认证信息
            if proxy_user and proxy_pass:
                proxy_str = f'{proxy_user}:{proxy_pass}@{proxy_host}:{proxy_port}'
            else:
                proxy_str = f'{proxy_host}:{proxy_port}'

            self.info.proxy_str = proxy_str
            self.info.proxy_proxies = {
                'http': f'socks5h://{proxy_str}',
                'https': f'socks5h://{proxy_str}'
            }
        else:
            self.info.proxy_str = None
            self.info.proxy_proxies = None

        # self.info.device.Bssid_bytes = bytes.fromhex(get_md5('00:14:bf:3a:8a:50'.encode()))
        client_type = kwargs.setdefault('client_type', 'QQ')
        self.info.device.Imei = '862542082770767'
        self.info.device.Mac = '89:C2:A9:C5:FA:E9'
        self.info.device.Bssid = '00:14:bf:3a:8a:50'

        self.info.key_tgtgt = get_random_bin(16)
        self.info.key_rand = get_random_bin(16)

        self.info.device.client_type = client_type
        if client_type == 'QQ':
            self.info.device.app_id = 537170024
            self.info.device.android_id = bytes.fromhex('d018b704652f41f4')
            self.info.device.package_name = 'com.tencent.mobileqq'
            self.info.device.var = '||A8.9.71.9fd08ae5'.encode()
            self.info.device.version = '8.8.85'
            self.info.device.sdk_version = '6.0.0.2497'
            self.info.device.Sig = 'A6 B7 45 BF 24 A2 C2 77 52 77 16 F6 F3 6E B6 8D'

        elif client_type == 'QQ_old':
            """旧版本支持"""
            self.info.device.app_id = 537116186
            self.info.device.package_name = 'com.tencent.mobileqq'
            self.info.device.android_id = '4cba299189222ca6'.encode()
            self.info.device.version = '8.8.85'
            self.info.device.Sig = 'A6 B7 45 BF 24 A2 C2 77 52 77 16 F6 F3 6E B6 8D'
            self.info.device.build_time = 1645432578
            self.info.device.sdk_version = '6.0.0.2497'
            self.info.device.var = '|877408608703263|A8.8.90.83e6c009'
            # self.info.device.app_id = 537119623


        elif client_type == 'Watch':
            self.info.device.app_id = 537140974
            self.info.device.android_id = bytes.fromhex('4cba299189224ca2')
            self.info.uin = '0'
            self.info.device.package_name = 'com.tencent.qqlite'
            self.info.device.version = '2.1.7'
            self.info.device.Sig = 'A6 B7 45 BF 24 A2 C2 77 52 77 16 F6 F3 6E B6 8D'
            self.info.device.build_time = int('1654570540')  # 2022-06-07 10:55:40 软件构建时间
            self.info.device.sdk_version = '6.0.0.2366'
            self.info.key_Pubkey = bytes.fromhex(
                '04 04 6E 31 F8 59 79 DF 7F 3D F0 31 CD C6 EB D9 B9 8E E2 E2 F6 3E FB 6E 79 BC 54 BF EE FB 0F 60 24 07 DA 8C 41 4A 34 EF 46 10 A7 95 48 0E F8 3F 0E')  # 49 长度的
            self.info.share_key = bytes.fromhex('54 9F 5C 3A B4 8D B9 16 DA 96 5F 3B 1B C1 03 4B')
            self.info.key_rand = bytes.fromhex('70 3F 79 79 55 78 2E 55 63 64 3A 44 38 49 7A 53')
            self.info.Guid = bytes.fromhex('9b6be0653a356f4fac89926f3f1ceb7e')
            # self.info.device.var = bytes(IMEI, 'utf-8')

        self._tcp = start_client(_func=self.UN_data, proxy=self.proxy)
        self.pack_list = {}

    def close(self):
        clients_info = {}
        if self._tcp:
            clients_info = disconnect_client(self._tcp)
        return Box({'status': 0, 'message': 'AndroidQQ已释放', 'clients_info': clients_info})

    def Set_TokenA(self, data):

        """
        appid

        """
        json_data = json.loads(data)

        mark = json_data.get('mark', 0)
        if mark == 1012:
            self.info.uin = str(json_data['UIN'])
            self.info.UN_Tlv_list.TGT_T10A = bytes.fromhex(json_data['TGT'])
            self.info.UN_Tlv_list.D2_T143 = bytes.fromhex(json_data['D2'])
            self.info.share_key = bytes.fromhex(json_data['Sharekey'].replace(' ', ''))
            self.info.Guid = bytes.fromhex(json_data['Guid'])
            self.info.device.app_id = int(json_data.get('Appid', self.info.device.app_id))
            self.info.UN_Tlv_list.userSt_Key = bytes.fromhex(json_data.get('userSt_Key', ''))
            self.info.UN_Tlv_list.userStSig = bytes.fromhex(json_data.get('userStSig', ''))
            self.info.UN_Tlv_list.wtSessionTicket = bytes.fromhex(json_data['wtSessionTicket'])
            self.info.UN_Tlv_list.wtSessionTicketKey = bytes.fromhex(json_data['wtSessionTicketKey'])

            if not self.info.UN_Tlv_list.wtSessionTicket:
                self.info.UN_Tlv_list.wtSessionTicket = bytes.fromhex(

                    '8EED6A0746FD906D06512F5F074BAD0F2D1729FA106EE98D40C9A5221F367579703360E29F4B7D4AE7FC25AE2D8DF241')
                if not self.info.UN_Tlv_list.wtSessionTicketKey:
                    self.info.UN_Tlv_list.wtSessionTicketKey = bytes.fromhex(

                        '04BEBF0116413CF54C3D21919F0164D8')

            self.info.emp_time = json_data.get('emp_time')

        else:
            appid = int(json_data.get('Appid', self.info.device.app_id))
            # appid = int('537085851')
            # print('appid', appid)
            self.info.uin = str(json_data['UIN'])
            self.info.UN_Tlv_list.TGT_T10A = bytes.fromhex(json_data['token_A4'])
            self.info.UN_Tlv_list.D2_T143 = bytes.fromhex(json_data['token_A2'])
            self.info.share_key = bytes.fromhex(json_data['Sharekey'].replace(' ', ''))
            self.info.Guid = bytes.fromhex(json_data['GUID_MD5'])
            self.info.device.app_id = appid  # 现在必须验证这个参数了
            self.info.UN_Tlv_list.userSt_Key = bytes.fromhex(json_data.get('T10E', ''))
            self.info.UN_Tlv_list.userStSig = bytes.fromhex(json_data.get('T114', ''))
            self.info.UN_Tlv_list.wtSessionTicket = bytes.fromhex(json_data['T133'])
            self.info.UN_Tlv_list.wtSessionTicketKey = bytes.fromhex(json_data['T134'])

        if json_data.get('cookies', None) is None:
            return
        self.info.cookies.skey = json_data['cookies'].get('skey', '')
        self.info.cookies.p_skey = json_data['cookies'].get('p_skey', {})
        self.info.cookies.client_key = json_data.get('cookies', {}).get('client_key', '')

        # self.info.cookies.client_key = json_data['cookies']['client_key']

    def get_tokenA(self):
        # print('get_tokenA', self.info)
        tokenA = {

            'UIN': self.info.uin,
            'D2': self.info.UN_Tlv_list.D2_T143.hex(),
            'TGT': self.info.UN_Tlv_list.TGT_T10A.hex(),
            'Sharekey': self.info.share_key.hex(),
            'Appid': self.info.device.app_id,
            'userSt_Key': self.info.UN_Tlv_list.userSt_Key.hex(),
            'userStSig': self.info.UN_Tlv_list.userStSig.hex(),
            'wtSessionTicket': self.info.UN_Tlv_list.wtSessionTicket.hex(),
            'wtSessionTicketKey': self.info.UN_Tlv_list.wtSessionTicketKey.hex(),
            'Guid': self.info.Guid.hex(),
            'cookies': self.info.cookies.__dict__,
            'emp_time': self.info.emp_time,
            'mark': 1012,  # 解析标识
        }
        return json.dumps(tokenA)

    def UN_data(self, data):
        """解包"""
        pack = pack_u(data)
        pack.get_int()
        pack_way = pack.get_byte()

        pack.get_byte()  # 00
        _len = pack.get_int()
        pack.get_bin(_len - 4)  # Uin bin
        _data = pack.get_all()
        if pack_way == 2:
            # 登录相关
            _data = TEA.decrypt(_data, '00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00')
        elif pack_way == 1:
            _data = TEA.decrypt(_data, self.info.share_key)
        else:
            _data = b''
            log.info('未知的解密类型')

        if not _data:
            return
        else:
            pack = pack_u(_data)
            _len = pack.get_int()
            part1 = pack.get_bin(_len - 4)
            _len = pack.get_int()
            part2 = pack.get_bin(_len - 4)
            # part1
            pack = pack_u(part1)
            seq = pack.get_int()
            pack.get_int()
            _len = pack.get_int()
            Tips = pack.get_bin(_len - 4).decode('utf-8')
            _len = pack.get_int()
            Cmd = pack.get_bin(_len - 4).decode('utf-8')
            # print('包序号', seq, '包类型', Cmd, part2.hex())
            if Tips != '':
                seq = self.info.seq  # 推送到最后一个包
                self.info.Tips = Tips
                # log.warning(f'Tips:{Tips}')
            # part2
            # log.info('包序号', ssoseq, '包类型', Cmd, part2.hex())
            if 0 < seq < 1000000:
                # log.info('包序号', seq, '包类型', Cmd, part2.hex())
                self.pack_list.update({seq: part2})
            else:
                # log.info('推送包', seq, '包类型', Cmd, part2.hex())
                pass

    def Tcp_send(self, data):
        self._tcp.sendall(data)
        start_time = time.time()  # 获取当前时间
        seq = self.info.seq
        while time.time() - start_time < 3:  # 检查是否已过去三秒
            data = self.pack_list.get(seq)
            if data is not None:
                self.pack_list.pop(seq)  # 删除已经取出的包
                break
            time.sleep(0.1)
        self.info.seq = seq + 1

        return data

    def tcp_task(self, req_func, rsp_func):
        buffer = req_func(self.info)
        if not self._tcp:
            return {'status': -89, 'message': '没有成功连接到服务器'}

        buffer = self.Tcp_send(buffer)
        if buffer == b'':
            if self.info.Tips is not None:
                status = -99
                message = self.info.Tips
            else:
                status = -91
                message = '返回空包体'

            return {'status': status, 'message': message}
        elif buffer is None:
            return {'status': -1, 'message': '未返回数据'}
        response = rsp_func(buffer)
        return {'status': 0, 'message': '请求成功', 'response': response}

    def scan_code_auth(self, **kwargs):
        """扫码授权"""

        def req_func(info):
            return wt_login.trans_emp_auth(info, **kwargs)

        def rsp_func(buffer):
            return wt_login.trans_emp_auth_res(buffer, self.info, **kwargs)

        return self.tcp_task(req_func, rsp_func)

    def exchange_emp(self, forcibly: bool = False):
        """更新缓存"""
        if self.info.emp_time and not forcibly:
            last_emp_time = datetime.datetime.strptime(self.info.emp_time, "%Y-%m-%d %H:%M:%S")
            current_time = datetime.datetime.now()
            time_difference = current_time - last_emp_time
            if time_difference < datetime.timedelta(hours=12):
                # 12个小时内不更新
                return {'status': 0, 'message': '无需更新'}

        def req_func(info):
            return wt_login.wtlogin_exchange_emp(info)

        def rsp_func(buffer):
            return wt_login.wtlogin_exchange_emp_rsp(self.info, buffer)

        return self.tcp_task(req_func, rsp_func)

    def no_tail_login(self):
        """无尾登录包"""

        def req_func(info):
            return OidbSvc_0x88d_1(info, 1042249288)

        return self.tcp_task(req_func, OidbSvc_0x88d_1_rep)

    def scan_Login(self, service_type: int, token: str):
        """扫码登录/辅助验证"""

        def req_func(info):
            return web_scanlogin(info, service_type, token)

        return self.tcp_task(req_func, web_scanlogin_req)

    def get_dev_login_info(self, iGetDevListType: int = 7):
        """
        获取设备登录信息
        参数:
            iGetDevListType: int, optional
                设备列表类型。如果未指定，将使用默认值 7。

        """

        def req_func(info):
            item = SvcReqGetDevLoginInfo(
                vecGuid=self.info.Guid,
                iTimeStam=1,
                strAppName='com.tencent.mobileqq',
                iRequireMax=20,
                iGetDevListType=iGetDevListType

            )
            return GetDevLoginInfo_profile(info, item)

        return self.tcp_task(req_func, GetDevLoginInfo_res)

    def del_login_info(self, key):
        """删除登录信息
        key= 获取设备信息返回
        """

        def req_func(info):
            return StatSvc.DelDevLoginInfo(info, key)

        return self.tcp_task(req_func, StatSvc.DelDevLoginInfo_res)

    def avatar_test_(self, **kwargs):
        """
        测试
        """

        data = avatar_test(self.info)
        data = self.Tcp_send(data)
        print(data.hex())

    def clean_device(self):
        """清理除自身外的其他设备"""
        response = self.get_dev_login_info()['response']
        online_list = json.loads(response)['4']
        for device in online_list:
            device_guid = device['1']
            device_address = device['4']
            device_info = device['5']
            device_key = device['7']
            if device_guid == self.info.Guid.hex():
                continue
            if len(device_key) > 5:
                self.del_login_info(key=device_key)
                print(f'删除{device_info} {device_address}')

    def get_summary_card(self, Uin: int = None, ComeFrom: int = 0):
        """"
        获取自身卡片
            参数:
            Uin: int, optional
                目标用户uin 不填获取自身
            ComeFrom: int, optional
                来源 0=自己 1=其他 31=搜索

        """

        def req_func(info):
            _ComeFrom = ComeFrom

            if Uin is None:
                _Uin = info.uin
            else:
                _Uin = Uin
                if ComeFrom == 0:
                    _ComeFrom = 1  # 其他

            Buffer = ReqSummaryCard(
                Uin=_Uin,
                ComeFrom=_ComeFrom,  # 自身是0,别人是其他 暂时不管细节
                IsFriend=True,
                GetControl=69181,
                AddFriendSource=10004,
                # stLocaleInfo=User_Locale_Info,
                SecureSig=bytes.fromhex('00'),
                ReqMedalWallInfo=True,  # 勋章墙,
                ReqNearbyGodInfo=True,  # 附近的信息
                ReqExtendCard=True,  # 请求扩展卡
                RichCardNameVer=True  # 富卡名称验证

            ).to_bytes()
            return SummaryCard_ReqSummaryCard(info, Buffer)

        return self.tcp_task(req_func, SummaryCard_ReqSummaryCard_rsp)

    def Qzone_like(self, target_Uin: int, title: str, feedskey: str):
        """
        空间点赞
        """

        def req_func(info):
            return SQQzoneSvc_like(info, target_Uin, title, feedskey)

        return self.tcp_task(req_func, SQQzoneSvc_like_rsp)

    def Qzone_publishmood(self, content: str):
        """
        空间发布信息
            :content 发送的内容
        """

        def req_func(info):
            return SQQzoneSvc_publishmood(info, content)

        return self.tcp_task(req_func, SQQzoneSvc_publishmood_rsp)

    def Qzone_delUgc(self, srcId: str):
        """
        空间删除信息
            :srcId 发送说说时会返回:tid
        """

        def req_func(info):
            return SQQzoneSvc_delUgc(info, srcId)

        return self.tcp_task(req_func, SQQzoneSvc_delUgc_rsp)

    def Qzone_shuoshuo(self, Uin, fullText: bool = False):
        """
         说说列表
            :param Uin int 说说的目标
            :param fullText bool 是否返回原始的全文信息
        """

        def req_func(info):
            return SQQzoneSvc_shuoshuo(info, Uin)

        def rsp_func(buffer):
            return SQQzoneSvc_shuoshuo_rsp(buffer, fullText)

        return self.tcp_task(req_func, rsp_func)

    def get_phone(self):
        """获取手机号"""

        def req_func(info):
            return OidbSvc_0xeb8(info)

        return self.tcp_task(req_func, OidbSvc_0xeb8_rep)

    def heartbeat(self):
        """心跳包"""

        def req_func(info):
            return Heartbeat_Alive(info)

        return self.tcp_task(req_func, Heartbeat_Alive_rsp)

    def unsubscribe(self, puin: int, cmd_type: int = 2):
        """
        取消订阅
            参数:
                puin: int 目标
                    2720152058 QQ团队
                    1770946116 安全中心
                    2290230341 QQ空间动态
                    2747277822 QQ手游
                    2010741172 QQ邮箱提醒


                cmd_type: int 默认2
        """

        def req_func(info):
            return OidbSvc_0xc96(info, puin, cmd_type)

        return self.tcp_task(req_func, OidbSvc_0xc96_rsp)

    def get_auth_list(self, start: int = 0, limit: int = 10):
        """
        获取授权列表
            参数:
                start = 0
                limit= 10
        """

        def req_func(info):
            return OidbSvc_0xc05(info, start, limit)

        return self.tcp_task(req_func, OidbSvc_0xc05_rep)

    def get_avatar_info(self, **kwargs):
        """获取头像信息"""

        def req_func(info):
            return GetAvatarInfo(info, **kwargs)

        return self.tcp_task(req_func, GetAvatarInfo_res)

    def login_register(self, lBid: int = 7, iStatus: int = 11, iOSVersion: int = 25, bOnlinePush: bool = True):
        """
        登录注册
            参数
                lBid: int
                    默认:7
                    0 登出 7 登录
                iStatus: int
                    默认:11
                    11:在线
                    21:离线
                iOSVersion: int
                    默认:25
                bOnlinePush: bool  是否在线推送
                    默认:True

        """

        def req_func(info):
            Buffer = SvcReqRegister(
                lUin=info.uin,
                lBid=lBid,
                iStatus=iStatus,
                iOSVersion=iOSVersion,
                cNetType=1,  # 网络类型
                vecGuid=info.Guid,
                strOSVer='7.1.2',  # Build.VERSION.RELEASE todo 不应该固定
                bOnlinePush=bOnlinePush,
                iLargeSeq=41,

            ).to_bytes()

            return StatSvc_register(info, Buffer)

        return self.tcp_task(req_func, StatSvc_register_rsp)

    def watch_scan_code(self, verify=False):
        """手表扫码"""
        data = wt_login.trans_emp(self.info, verify)
        data = self.Tcp_send(data)
        data = wt_login.trans_emp_res(data, self.info, verify)
        return data

    def login(self, **kwargs):
        """登录"""

        data = wt_login.login(self.info, **kwargs)
        data = self.Tcp_send(data)
        wt_login.login_res(data, self.info)

    def loginH(self, **kwargs):
        """登录 混合模式"""
        self.info.uin = kwargs['uin']
        self.info.password = kwargs['password']
        self.info.device.client_type = 'AndH'
        data = wt_login.login_H(self.info, **kwargs)

        data = self.Tcp_send(data)
        wt_login.login_res(data, self.info)

    def login_captcha(self, Ticket: str):
        """提交验证码"""
        data = wt_login.login_captcha(self.info, Ticket)
        data = self.Tcp_send(data)
        wt_login.login_res(data, self.info)

    def get_specified_info(self):
        """获取指定信息"""
        # 兼容其他源码
        data = {
            "UIN": self.info.uin,
            "GUID_MD5": self.info.Guid.hex(),
            "token_A4": self.info.UN_Tlv_list.T10A_token_A4.hex(),
            "token_A2": self.info.UN_Tlv_list.T143_token_A2.hex(),
            "Sharekey": self.info.share_key.hex(),
            "T134": self.info.UN_Tlv_list.T134.hex(),
            "T133": self.info.UN_Tlv_list.T133.hex(),
            "T10E": self.info.UN_Tlv_list.T10E.hex(),
            "T114": self.info.UN_Tlv_list.T114.hex(),
            "device_APPID": self.info.device.app_id.to_bytes(4, 'big').hex()
        }
        return json.dumps(data)

    def get_unread_msg_count(self):
        """获取未读消息"""
        data = MessageSvc.PullUnreadMsgCount(self.info)
        data = self.Tcp_send(data)
        if data:
            data = MessageSvc.PullUnreadMsgCount_res(data)
        return data

    def del_auth_info(self, **kwargs):
        """删除授权信息
        appid= 要删除的id
        """
        data = OidbSvc.P0xccd(self.info, **kwargs)
        data = self.Tcp_send(data)
        if data:
            data = OidbSvc.P0xccd_res(data)
        return data

    def get_friends_online_list(self, **kwargs):
        """获取在线好友列表
        'ifgetFriendVideoAbi': 是否获取朋友的视频能力。布尔值，可选，默认为False。
        'isReqCheckIn': 是否请求签到。布尔值，可选，默认为False。
        'ifShowTermType': 是否显示好友的设备类型。布尔值，可选，默认为True。
        'version': 版本号。32位整数，可选，默认为33。
        'cSrcType': 来源类型。32位整数，可选，默认为1。
        """
        data = friendlist.GetSimpleOnlineFriendInfoReq(self.info)
        data = self.Tcp_send(data)
        if data:
            data = friendlist.GetSimpleOnlineFriendInfoReq_res(data)
        return data

    def set_avatar(self):

        data = OidbSvc_0xdfa_0(self.info)
        data = self.Tcp_send(data)
        print(data.hex())

        return data

    def get_online(self):

        """获取在线状态"""

        data = OidbSvcTrpcTcp_0xfe1_2(self.info)
        data = self.Tcp_send(data)
        print('返回', data.hex())

        return data

    def get_cookie(self, domain: str):
        """
        :param domain: 域名
        :return:
        """
        p_skey = self.info.cookies.p_skey.get(domain, None)
        if p_skey is None:
            return None
        return f"uin=o{self.info.uin}; skey={self.info.cookies.skey}; p_uin=o{self.info.uin}; p_skey={p_skey};"

    def get_bkn(self):
        """
        获取bkn
        :return:
        """
        return qq_bkn(self.info.cookies.skey)

    def get_qq_level(self):
        """
        获取qq等级
        :return .get('levelInfo')
        """
        return qq_level_index(self.info, self.get_cookie("ti.qq.com"))

    def get_lv_task_status(self, query: bool = False):
        """获取等级任务状态"""
        return GetLevelStatus(self.info, self.get_cookie("ti.qq.com"), query)

    def get_lv_task(self):
        """获取等级任务"""
        return GetLevelTask(self.info, self.get_cookie("ti.qq.com"))

    def refresh_task(self, task_id: str):
        """刷新任务状态"""
        return RefreshTask(self.info, self.get_cookie("ti.qq.com"), task_id)

    def sign_in(self):
        """签到"""
        return WriteMindJar(self.info, self.get_cookie("ti.qq.com"), self.info.cookies.skey)

    def change_psw_getsms(self, mobile):
        """修改密码，获取验证码
        :param mobile: 手机号
        """
        return change_psw_getsms(self.info, self.get_cookie("accounts.qq.com"), mobile)

    def weishi_up(self):
        """微视任务"""
        return weishi_up_(self.info)

    def Music_task(self):
        """音乐"""
        return Music(self.info).task()

    def get_clientkey(self, domain: str = 'https://qzone.qq.com'):
        """"
        获取客户端key
        :param domain: 域名
       """
        return f'https://ssl.ptlogin2.qq.com/jump?clientuin={self.info.uin}&clientkey={self.info.cookies.client_key}&keyindex=19&pt_mq=0&u1={domain}'

    def qq_show_replace(self, show='女性带眼镜'):
        """
        更换QQ秀
            dict_keys(['女性带眼镜', '女性_紫星连衣裙', '女性_带口罩', '女性_兔兔发箍', '女性_元气针织帽', '女性_白色百褶裙'])


        """

        def req_func(info):
            return MobProxy_SsoHandle(info, show)

        def rsp_func(buffer):
            return MobProxy_SsoHandle_rsp(buffer, show)

        return self.tcp_task(req_func, rsp_func)

    def lv_Friend(self):
        """加好友任务"""
        selected = random.sample(bot_uin, 3)
        try:
            Friend = Friends(self.info, self.get_bkn(), self.info.uin, self.get_cookie('qun.qq.com'))
            success = 0
            for f_uin in selected:
                rsp = Friend.del_friend(f_uin)
                if not rsp.status:
                    continue
                rsp = Friend.add_friend(f_uin)
                if not rsp.status:
                    continue
                success += 1
            task = self.refresh_task('1').get('response', {}).get('task', {})
            finished_accelerate_days = task.get('finished_accelerate_days', 0)
            return Box(status=True, message=f'新增活跃天数{finished_accelerate_days}天',
                       finishedAccelerateDays=finished_accelerate_days)

        except Exception as e:
            return Box(status=False, message=f'好友活跃任务异常{e}')

        finally:
            for f_uin in selected:
                delete_qq_friend(self.info, self.info.uin, f_uin, self.get_bkn(), self.get_cookie('qzone.qq.com'))

    def lv_cm_show(self):
        """"厘米秀装扮"""
        try:
            shows = ['女性带眼镜', '女性_紫星连衣裙', '女性_带口罩', '女性_兔兔发箍', '女性_元气针织帽',
                     '女性_白色百褶裙']
            for i in range(2):
                show = random.choice(shows)
                shows.remove(show)
                self.qq_show_replace(show)
            task = self.refresh_task('27').get('response', {}).get('task', {})
            if not task:
                return Box(status=False, message='刷新任务异常')
            button_text = task.get('button_text')
            if button_text == '已完成':
                finished_accelerate_days = task.get('accelerate_days', 0)
            else:
                finished_accelerate_days = 0
            return Box(status=True, message=f'新增活跃天数{finished_accelerate_days}天',
                       finishedAccelerateDays=finished_accelerate_days)
        except Exception as e:
            return Box(status=False, message=f'厘米秀任务异常{e}')

    def lv_music(self):
        """音乐任务"""
        try:

            self.Music_task()
            finished_accelerate_days = 0
            for i in range(15):
                logger.info('正在等待音乐任务完成，剩余次数{}'.format(20 - i))
                time.sleep(1)
                task = self.refresh_task('19').get('response', {}).get('task', {})
                button_text = task.get('button_text')
                if button_text == '已完成':
                    finished_accelerate_days = task.get('accelerate_days', 0)
                    break
            logger.success(f'音乐任务完成,新增活跃{finished_accelerate_days}天')
            return Box(status=True, message=f'新增活跃天数{finished_accelerate_days}天',
                       finishedAccelerateDays=finished_accelerate_days)

        except Exception as e:
            return Box(status=False, message=f'音乐任务异常{e}')

    def lv_clock_in(self):
        """打卡任务"""
        self.sign_in()
        self.refresh_task('3')

    def lv_weishi(self):
        self.weishi_up()
        self.get_lv_task()

    def lv_continuous_login(self):

        self.get_summary_card()
        self.get_lv_task()

    def lv_Qzone(self, content=None):
        """空间任务"""
        content_list = [
            ' 小荷才露尖尖角，早有蜻蜓立上头',
            ' 有三秋桂子，十里荷花',
            ' 藕花珠缀，犹似汗凝妆',
            ' 一缕清香，一缕淡香',
            ' 接天莲叶无穷碧，映日荷花别样红',
            '能不能停下来，看看那个满眼泪花奔向你的我。',
            '承诺常常很像蝴蝶，美丽的盘旋后就不见了。'
        ]
        random_content = random.choice(content_list)
        if not content:
            content = random_content

        logger.info(f'空间任务内容：{content}')
        try:
            rsp = self.Qzone_publishmood(content).get('response', {})
            tid = rsp.get('Busi', {}).get('tid', '')
            self.get_qq_level()
            self.Qzone_delUgc(tid)
            task = self.refresh_task('2').get('response', {}).get('task', {})
            if not task:
                return Box(status=False, message='刷新任务异常')
            button_text = task.get('button_text')
            if button_text == '去领取':
                finished_accelerate_days = task.get('accelerate_days', 0)
            else:
                finished_accelerate_days = 0
            return Box(status=True, message=f'新增活跃天数{finished_accelerate_days}天',
                       finishedAccelerateDays=finished_accelerate_days)
        except Exception as e:
            return Box(status=False, message=f'空间任务异常{e}')

    def lv_extra_task_up(self, lv_music=True, zone_content=None):
        """升级所有额外任务"""
        rsp = self.exchange_emp()
        if rsp['status'] != 0:
            return Box(status=False, message='emp' + rsp['message'])
        rsp = self.no_tail_login()
        status = rsp['status']
        if status != 0:
            return Box(status=False, message=rsp['message'], status_int=status)

        task_functions = {
            '连续登录QQ': self.lv_continuous_login,
            '发布一条空间说说': lambda: self.lv_Qzone(content=zone_content),
            '去日签卡打一次卡': self.lv_clock_in,
            '去QQ音乐听歌30分钟+0.5天': self.lv_music,
            '加一位好友': self.lv_Friend,
            '去超级QQ秀更新装扮并保存': self.lv_cm_show,
            '去微视APP看视频': self.lv_weishi,
        }

        task_status = self.get_lv_task_status(True)
        execute_task = False
        for task_name, function in task_functions.items():

            if task_name == '去QQ音乐听歌30分钟+0.5天' and not lv_music:
                logger.info(f'{self.info.uin[:2]}跳过音乐')
                continue  # 如果任务是'去QQ音乐听歌30分钟+0.5天'并且设置为不可选执行，则跳过执行
            is_done = task_status.get(task_name, {}).get('is_done', None)
            if not is_done:
                logger.info(f'{self.info.uin[:2]}执行{task_name}')
                function()
                execute_task = True

        level = self.get_summary_card().get('response', {}).get('5', 0)
        if execute_task:
            task_status = self.get_lv_task_status(True)

        done_count = task_status.get('done_count', None)
        logger.info(f'{self.info.uin[:2]}已完成任务数量{done_count}')
        return Box(status=True, level=level, done_count=done_count, task_status=task_status)

    def get_http_ip(self):
        """获取http代理"""
        return GetHttpIp(self.info.proxy_proxies)

    def get_credit(self):
        """获取信用分"""
        return Box(credit_score(self.info, self.info.cookies.client_key).query_common_credit())

    @property
    def tcp(self):
        return self._tcp



from typing import Union, List, cast

from Jce_b import IJceStruct
from Jce_b.typing import JceReader

from .single_feed import *


class mobile_applist_rsp(IJceStruct):
    album_area_info: dict = None
    album_count: int = 0

    all_applist_data: list = []
    attach_info: str = ""
    auto_load: int = 0
    dailyShuoShuoCount: int = 0
    extend_info: dict = None
    hasmore: int = 0
    kantu_album_count: int = 0
    life_moment_info: dict = None
    lossy_service: int = 0
    mapEx: dict[str, bytes] = None
    photo_count: int = 0
    remain_count: int = 0

    share_album: IJceStruct = None

    shuoshuo_timer_unpublished_count: int = 0
    stMemoryInfo: dict = None
    video_count: int = 0

    def read_from(self, reader: JceReader) -> None:
        # reader.read_head()

        self.all_applist_data = reader.read_list(single_feed, 0)

        self.hasmore = reader.read_any(1)
        self.remain_count = reader.read_any(2)
        self.attach_info = reader.read_any(3)
        self.auto_load = reader.read_any(4)

        self.share_album = reader.read_object(single_feed)
        self.lossy_service = reader.read_any(7)
        self.extend_info = reader.read_any(8)
        self.album_count = reader.read_any(9)
        self.photo_count = reader.read_any(10)
        self.video_count = reader.read_any(11)
        self.stMemoryInfo = reader.read_any_with_tag(12)
        self.mapEx = reader.read_any(13)
        self.shuoshuo_timer_unpublished_count = reader.read_any(14)
        self.life_moment_info = reader.read_any_with_tag(15)
        self.album_area_info = reader.read_any_with_tag(16)
        self.kantu_album_count = reader.read_any(17)
        self.dailyShuoShuoCount = reader.read_any(18)

    def to_bytes(self) -> Union[bytes, bytearray]:
        pass



import zlib

from Jce import JceInputStream, JceStruct

from .SvcReqGetDevLoginInfo import *
from .. import PackHeadNoToken, Pack_, Un_jce_Head, Un_jce_Head_2


def GetDevLoginInfo_profile(info, item: SvcReqGetDevLoginInfo):
    """获取设备登录信息"""
    _buffer = item.to_bytes()
    _buffer = JceWriter().write_jce_struct(_buffer, 0)
    _buffer = JceWriter().write_map({'SvcReqGetDevLoginInfo': _buffer}, 0)
    _buffer = PackHeadNoToken(info, _buffer, 'StatSvc.GetDevLoginInfo', 'StatSvc', 'SvcReqGetDevLoginInfo')
    _buffer = Pack_(info, _buffer, Types=11, encryption=1, sso_seq=info.seq)
    return _buffer


def GetDevLoginInfo_res(data):
    if data[0] == 120:
        data = zlib.decompress(data)
    data = Un_jce_Head(data)
    data = Un_jce_Head_2(data)
    stream = JceInputStream(data)
    s = JceStruct()
    s.read_from(stream)
    return s.to_json()



# package QMF_PROTOCAL;
from typing import Union

from Jce_b import IJceStruct, JceReader, JceWriter


class QmfClientIpInfo(IJceStruct):
    ClientIpv4: int = 0
    ClientIpv6: bytes = bytes()
    ClientPort: int = 0
    IpType: int = 0

    def read_from(self, reader: JceReader) -> None:
        pass

    def to_bytes(self) -> Union[bytes, bytearray]:
        Jce = JceWriter()
        Jce.write_object(self.IpType, 0)
        Jce.write_object(self.ClientPort, 1)
        Jce.write_object(self.ClientIpv4, 2)
        if self.ClientIpv6 is not None:
            Jce.write_object(self.ClientIpv6, 3)

        return Jce.bytes()



# struct SummaryCard;
import json
import zlib

from Jce import JceInputStream, JceStruct
from Jce_b import JceWriter, JceReader

from AndroidQQ.struct import PackHeadNoToken, Pack_, Un_jce_Head
from AndroidQQ.struct.SummaryCard import ReqSummaryCard


def SummaryCard_ReqSummaryCard(info, Buffer):
    """获取摘要卡"""

    Buffer = JceWriter().write_jce_struct(Buffer, 0)

    Buffer = JceWriter().write_map({'ReqHead': bytes.fromhex('0A 00 02 0B'), 'ReqSummaryCard': Buffer},
                                   0)  # 似乎新版有更多的验证,因此用旧的头部

    Buffer = PackHeadNoToken(info, Buffer, 'SummaryCard.ReqSummaryCard',
                             'SummaryCardServantObj', 'ReqSummaryCard')
    Buffer = Pack_(info, Buffer, Types=11, encryption=1, sso_seq=info.seq)
    return Buffer


def SummaryCard_ReqSummaryCard_rsp(Buffer):
    if Buffer[0] == 120:
        Buffer = zlib.decompress(Buffer)

    data = Un_jce_Head(Buffer)
    _map = JceReader(data).read_map(0)
    _dict = _map.get('RespSummaryCard', None)
    if _dict is None:
        return None
    # 包体太大了,自动解析
    RespSummaryCard = _dict['SummaryCard.RespSummaryCard']
    stream = JceInputStream(RespSummaryCard)
    jce = JceStruct()
    jce.read_from(stream)
    return json.loads(jce.to_json())


if __name__ == '__main__':
    pass



from AndroidQQ.struct import Pack_, Pack_Head, PackHeadNoToken


def avatar_test(info):
    """
    """
    buffer = bytes.fromhex(
        '08 00 01 06 04 72 65 73 70 1D 00 00 39 0A 02 57 20 27 53 19 00 01 0A 02 57 20 27 53 1C 21 D4 A3 3D 00 00 13 08 90 04 10 FD CF A1 EC 86 80 80 80 02 18 00 20 DB 86 03 4C 5C 6C 7C 8C 9C AC 0B 22 E5 95 95 0B 4C 0B ')
    buffer = PackHeadNoToken(info, buffer, 'OnlinePush.RespPush','OnlinePush','SvcRespPushMsg')
    buffer = Pack_(info, buffer, Types=11, encryption=1, sso_seq=info.seq)
    return buffer
